@@ -183,8 +183,11 @@ RclConfig::RclConfig(const string *argcnf)
 
 bool RclConfig::updateMainConfig()
 {
-    m_conf = new ConfStack<ConfTree>("recoll.conf", m_cdirs, true);
-    if (m_conf == 0 || !m_conf->ok()) {
+    ConfStack<ConfTree> *newconf = 
+	new ConfStack<ConfTree>("recoll.conf", m_cdirs, true);
+    if (newconf == 0 || !newconf->ok()) {
+	if (m_conf)
+	    return false;
 	string where;
 	stringsToString(m_cdirs, where);
 	m_reason = string("No/bad main configuration file in: ") + where;
@@ -211,6 +214,8 @@ bool RclConfig::updateMainConfig()
 	TextSplit::noNumbers();
     }
 
+    delete m_conf;
+    m_conf = newconf;
     m_skpnstate.init(this, m_conf, "skippedNames");
     m_rmtstate.init(this, m_conf, "indexedmimetypes");
     return true;
@@ -740,8 +745,8 @@ bool RclConfig::getFieldConfParam(const string &name, const string &sk,
 
 string RclConfig::getMimeViewerDef(const string &mtype, const string& apptag)
 {
-    LOGDEB(("RclConfig::getMimeViewerDef: mtype %s apptag %s\n",
-            mtype.c_str(), apptag.c_str()));
+    LOGDEB2(("RclConfig::getMimeViewerDef: mtype [%s] apptag [%s]\n",
+	     mtype.c_str(), apptag.c_str()));
     string hs;
     if (mimeview == 0)
 	return hs;
@@ -850,6 +855,10 @@ string RclConfig::getStopfile()
 {
     return path_cat(getConfDir(), "stoplist.txt");
 }
+string RclConfig::getPidfile()
+{
+    return path_cat(getConfDir(), "index.pid");
+}
 
 list<string>& RclConfig::getSkippedNames()
 {
