@@ -164,6 +164,7 @@ bool TextSplit::isCJK(int c)
 
 bool          TextSplit::o_processCJK = true;
 unsigned int  TextSplit::o_CJKNgramLen = 2;
+bool          TextSplit::o_noNumbers = false;
 
 // Do some checking (the kind which is simpler to do here than in the
 // main loop), then send term to our client.
@@ -186,7 +187,7 @@ inline bool TextSplit::emitterm(bool isspan, string &w, int pos,
 	    }
 	}
 	if (pos != m_prevpos || l != m_prevlen) {
-	    bool ret = m_cb->takeword(w, pos, btstart, btend);
+	    bool ret = takeword(w, pos, btstart, btend);
 	    m_prevpos = pos;
 	    m_prevlen = w.length();
 	    return ret;
@@ -212,12 +213,15 @@ inline bool TextSplit::emitterm(bool isspan, string &w, int pos,
  */
 inline bool TextSplit::doemit(bool spanerase, int bp, bool spanemit)
 {
-    LOGDEB3(("TextSplit::doemit:spn [%s] sp %d wrdS %d wrdL %d spe %d bp %d\n",
-	     span.c_str(), spanpos, wordStart, wordLen, spanerase, bp));
+    LOGDEB3(("TextSplit::doemit:spn [%s] sp %d wrdS %d wrdL %d spe %d bp %d "
+             "innum %d\n", m_span.c_str(), m_spanpos, m_wordStart, 
+             m_wordLen, spanerase, bp, m_inNumber));
 
     // Emit span. When splitting for query, we only emit final spans
     bool spanemitted = false;
     if (!(m_flags & TXTS_NOSPANS) && 
+        !((m_wordLen == m_span.length()) && 
+          (o_noNumbers) && m_inNumber) &&
 	((spanemit && !(m_flags & TXTS_ONLYSPANS)) || spanerase) ) {
 	// Maybe trim at end. These are chars that we would keep inside 
 	// a span, but not at the end
@@ -243,6 +247,7 @@ inline bool TextSplit::doemit(bool spanerase, int bp, bool spanemit)
 
     // Emit word if different from span and not 'no words' mode
     if (!(m_flags & TXTS_ONLYSPANS) && m_wordLen && 
+        !(o_noNumbers && m_inNumber) &&
 	(!spanemitted || m_wordLen != m_span.length())) {
 	string s(m_span.substr(m_wordStart, m_wordLen));
 	if (!emitterm(false, s, m_wordpos, bp - m_wordLen, bp))
@@ -340,7 +345,9 @@ bool TextSplit::text_to_words(const string &in)
 	    break;
 	case '-':
 	case '+':
-	    if (m_wordLen == 0) {
+	    if (m_wordLen == 0 || 
+                (m_inNumber && (m_span[m_span.length() - 1] == 'e' ||
+                                m_span[m_span.length() - 1] == 'E'))) {
 		if (whatcc(it[it.getCpos()+1]) == DIGIT) {
 		    m_inNumber = true;
 		    m_wordLen += it.appendchartostring(m_span);
@@ -360,7 +367,8 @@ bool TextSplit::text_to_words(const string &in)
 	case ',':
 	    if (m_inNumber) {
 		// 132.jpg ?
-		if (whatcc(it[it.getCpos()+1]) != DIGIT)
+                int wn = it[it.getCpos()+1];
+		if (whatcc(wn) != DIGIT && wn != 'e' && wn != 'E')
 		    goto SPACE;
 		m_wordLen += it.appendchartostring(m_span);
 		curspanglue = cc;
@@ -373,11 +381,21 @@ bool TextSplit::text_to_words(const string &in)
 		// will be split as .x-errs, x, errs but not x-errs
 		// A final comma in a word will be removed by doemit
 		if (cc == '.') {
+                    // Check for number like .1
+                    if (m_span.length() == 0 &&
+                        whatcc(it[it.getCpos()+1]) == DIGIT) {
+                        m_inNumber = true;
+                        m_wordLen += it.appendchartostring(m_span);
+                        curspanglue = cc;
+                        break;
+                    }
+                            
 		    if (m_wordLen) {
 			// Disputable special case: set spanemit to
-			// true when encountering a '.' while spanglue is '_'. Think of
-			// a_b.c Done because to avoid breaking stuff after changing
-			// '_' from wordchar to spanglue
+			// true when encountering a '.' while spanglue
+			// is '_'. Think of a_b.c Done because to
+			// avoid breaking stuff after changing '_'
+			// from wordchar to spanglue
 			if (!doemit(false, it.getBpos(), curspanglue == '_'))
 			    return false;
 			curspanglue = cc;
@@ -494,6 +512,9 @@ bool TextSplit::text_to_words(const string &in)
 
 	default:
 	NORMALCHAR:
+            if (m_inNumber && c != 'e' && c != 'E') {
+                m_inNumber = false;
+            }
 	    m_wordLen += it.appendchartostring(m_span);
 	    break;
 	}
@@ -558,7 +579,7 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
 	    unsigned int loopbeg = (m_flags & TXTS_NOSPANS) ? nchars-1 : 0;
 	    unsigned int loopend = (m_flags & TXTS_ONLYSPANS) ? 1 : nchars;
 	    for (unsigned int i = loopbeg; i < loopend; i++) {
-		if (!m_cb->takeword(it.buffer().substr(boffs[i], 
+		if (!takeword(it.buffer().substr(boffs[i], 
 						       btend-boffs[i]),
 				m_wordpos - (nchars-i-1), boffs[i], btend)) {
 		    return false;
@@ -579,7 +600,7 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
     // first
     if ((m_flags & TXTS_ONLYSPANS) && nchars > 0 && nchars != o_CJKNgramLen)  {
 	unsigned int btend = it.getBpos(); // Current char is out
-	if (!m_cb->takeword(it.buffer().substr(boffs[0], 
+	if (!takeword(it.buffer().substr(boffs[0], 
 					       btend-boffs[0]),
 			    m_wordpos - nchars,
 			    boffs[0], btend)) {
@@ -595,12 +616,12 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
     return true;
 }
 
-// Callback class for countWords 
-class utSplitterCB : public TextSplitCB {
+// Specialization for countWords 
+class TextSplitCW : public TextSplit {
  public:
     int wcnt;
-    utSplitterCB() : wcnt(0) {}
-    bool takeword(const string &term, int pos, int bs, int be) {
+    TextSplitCW(Flags flags) : TextSplit(flags), wcnt(0) {}
+    bool takeword(const string &, int, int, int) {
 	wcnt++;
 	return true;
     }
@@ -608,10 +629,9 @@ class utSplitterCB : public TextSplitCB {
 
 int TextSplit::countWords(const string& s, TextSplit::Flags flgs)
 {
-    utSplitterCB cb;
-    TextSplit splitter(&cb, flgs);
+    TextSplitCW splitter(flgs);
     splitter.text_to_words(s);
-    return cb.wcnt;
+    return splitter.wcnt;
 }
 
 bool TextSplit::hasVisibleWhite(const string &in)
@@ -726,12 +746,13 @@ bool TextSplit::stringToStrings(const string &s, list<string> &tokens)
 
 using namespace std;
 
-// A small class to hold state while splitting text
-class mySplitterCB : public TextSplitCB {
+class myTextSplit : public TextSplit {
     int first;
     bool nooutput;
  public:
-    mySplitterCB() : first(1), nooutput(false) {}
+    myTextSplit(Flags flags = Flags(TXTS_NONE)) : 
+        TextSplit(flags),first(1), nooutput(false) 
+    {}
     void setNoOut(bool val) {nooutput = val;}
     bool takeword(const string &term, int pos, int bs, int be) {
 	if (nooutput)
@@ -750,7 +771,8 @@ static string teststring =
 	    "Un bout de texte \nnormal. 2eme phrase.3eme;quatrieme.\n"
 	    "\"Jean-Francois Dockes\" <jfd@okyz.com>\n"
 	    "n@d @net .net t@v@c c# c++ o'brien 'o'brien' l'ami\n"
-	    "134 +134 -14 -1.5 +1.5 1.54e10 1,2 1,2e30\n"
+            "data123\n"
+	    "134 +134 -14 0.1 .1 2. -1.5 +1.5 1,2 1.54e10 1,2e30 .1e10 1.e-8\n"
 	    "@^#$(#$(*)\n"
 	    "192.168.4.1 one\n\rtwo\r"
 	    "Debut-\ncontinue\n" 
@@ -762,6 +784,7 @@ static string teststring =
 	    " -wl,--export-dynamic "
 	    " ~/.xsession-errors "
 ;
+
 static string teststring1 = " nouvel-an ";
 
 static string thisprog;
@@ -771,6 +794,7 @@ static string usage =
     "   -S: no output\n"
     "   -s:  only spans\n"
     "   -w:  only words\n"
+    "   -n:  no numbers\n"
     "   -k:  preserve wildcards (?*)\n"
     "   -c: just count words\n"
     "   -C [charset] : input charset\n"
@@ -792,6 +816,7 @@ static int        op_flags;
 #define OPT_c     0x8
 #define OPT_k     0x10
 #define OPT_C     0x20
+#define OPT_n     0x40
 
 int main(int argc, char **argv)
 {
@@ -811,6 +836,7 @@ int main(int argc, char **argv)
                 charset = *(++argv); argc--; 
                 goto b1;
 	    case 'k':	op_flags |= OPT_k; break;
+	    case 'n':	op_flags |= OPT_n; break;
 	    case 's':	op_flags |= OPT_s; break;
 	    case 'S':	op_flags |= OPT_S; break;
 	    case 'w':	op_flags |= OPT_w; break;
@@ -821,18 +847,16 @@ int main(int argc, char **argv)
     DebugLog::getdbl()->setloglevel(DEBDEB1);
     DebugLog::setfilename("stderr");
 
-    mySplitterCB cb;
     TextSplit::Flags flags = TextSplit::TXTS_NONE;
 
-    if (op_flags&OPT_S)
-	cb.setNoOut(true);
-
     if (op_flags&OPT_s)
 	flags = TextSplit::TXTS_ONLYSPANS;
     else if (op_flags&OPT_w)
 	flags = TextSplit::TXTS_NOSPANS;
     if (op_flags & OPT_k) 
 	flags = (TextSplit::Flags)(flags | TextSplit::TXTS_KEEPWILD); 
+    if (op_flags & OPT_n)
+	TextSplit::noNumbers();
 
     string odata, reason;
     if (argc == 1) {
@@ -867,7 +891,9 @@ int main(int argc, char **argv)
 	int n = TextSplit::countWords(data, flags);
 	cout << n << " words" << endl;
     } else {
-	TextSplit splitter(&cb,  flags);
+	myTextSplit splitter(flags);
+        if (op_flags&OPT_S)
+            splitter.setNoOut(true);
 	splitter.text_to_words(data);
     }    
 }
