@@ -201,9 +201,15 @@ Usage(FILE *where = stderr)
 }
 
 static RclConfig *config;
-RclConfig *RclConfig::getMainConfig() 
+
+void lockorexit(Pidfile *pidfile)
 {
-    return config;
+    pid_t pid;
+    if ((pid = pidfile->open()) != 0) {
+	cerr << "Can't become exclusive indexer: " << pidfile->getreason() << 
+	    ". Return (other pid?): " << pid << endl;
+	exit(1);
+    }
 }
 
 int main(int argc, const char **argv)
@@ -268,12 +274,16 @@ int main(int argc, const char **argv)
 	exit(1);
     }
     bool rezero(op_flags & OPT_z);
+    Pidfile pidfile(config->getPidfile());
 
-    if (setpriority(PRIO_PGRP, 0, 20) != 0) {
+    if (setpriority(PRIO_PROCESS, 0, 20) != 0) {
         LOGINFO(("recollindex: can't setpriority(), errno %d\n", errno));
     }
-    
+
     if (op_flags & (OPT_i|OPT_e)) {
+	lockorexit(&pidfile);
+	pidfile.write_pid();
+
 	list<string> filenames;
 
 	if (argc == 0) {
@@ -316,15 +326,17 @@ int main(int argc, const char **argv)
     } else if (op_flags & OPT_m) {
 	if (argc != 0) 
 	    Usage();
+	lockorexit(&pidfile);
 	if (!(op_flags&OPT_D)) {
 	    LOGDEB(("recollindex: daemonizing\n"));
 	    daemon(0,0);
 	}
         // Not too sure if I have to redo the nice thing after daemon(),
         // can't hurt anyway (easier than testing on all platforms...)
-        if (setpriority(PRIO_PGRP, 0, 20) != 0) {
+        if (setpriority(PRIO_PROCESS, 0, 20) != 0) {
             LOGINFO(("recollindex: can't setpriority(), errno %d\n", errno));
         }
+	pidfile.write_pid();
 	if (sleepsecs > 0) {
 	    LOGDEB(("recollindex: sleeping %d\n", sleepsecs));
 	    sleep(sleepsecs);
@@ -356,6 +368,8 @@ int main(int argc, const char **argv)
         cerr << "Not yet" << endl;
         return 1;
     } else {
+	lockorexit(&pidfile);
+	pidfile.write_pid();
 	confindexer = new ConfIndexer(config, &updater);
 	bool status = confindexer->index(rezero, ConfIndexer::IxTAll);
 	if (!status) 
