@@ -45,7 +45,7 @@ bool MimeHandlerExecMultiple::startCmd()
     LOGDEB(("MimeHandlerExecMultiple::startCmd\n"));
     if (params.empty()) {
 	// Hu ho
-	LOGERR(("MHExecMultiple::mkDoc: empty params\n"));
+	LOGERR(("MHExecMultiple::startCmd: empty params\n"));
 	m_reason = "RECFILTERROR BADCONFIG";
 	return false;
     }
@@ -169,6 +169,10 @@ bool MimeHandlerExecMultiple::next_document()
     if (m_ipath.length()) {
         obuf << "Ipath: " << m_ipath.length() << "\n" << m_ipath;
     }
+    if (!m_dfltInputCharset.empty()) {
+        obuf << "DflInCS: " << m_dfltInputCharset.length() << "\n" 
+	     << m_dfltInputCharset;
+    }
     obuf << "Mimetype: " << m_mimeType.length() << "\n" << m_mimeType;
     obuf << "\n";
     if (m_cmd.send(obuf.str()) < 0) {
@@ -185,6 +189,7 @@ bool MimeHandlerExecMultiple::next_document()
     bool subdocerror_received = false;
     string ipath;
     string mtype;
+    string charset;
     for (int loop=0;;loop++) {
         string name, data;
         if (!readDataElement(name, data)) {
@@ -199,18 +204,18 @@ bool MimeHandlerExecMultiple::next_document()
         } else if (!stringlowercmp("eofnow:", name)) {
             LOGDEB(("MHExecMultiple: got EOFNOW\n"));
             eofnow_received = true;
-        } else if (!stringlowercmp("subdocerror:", name)) {
-            LOGDEB(("MHExecMultiple: got SUBDOCERROR\n"));
-	    subdocerror_received = true;
         } else if (!stringlowercmp("fileerror:", name)) {
             LOGDEB(("MHExecMultiple: got FILEERROR\n"));
 	    fileerror_received = true;
         } else if (!stringlowercmp("subdocerror:", name)) {
             LOGDEB(("MHExecMultiple: got SUBDOCERROR\n"));
-	    return false;
+	    subdocerror_received = true;
         } else if (!stringlowercmp("ipath:", name)) {
             ipath = data;
             LOGDEB(("MHExecMultiple: got ipath [%s]\n", data.c_str()));
+        } else if (!stringlowercmp("charset:", name)) {
+            charset = data;
+            LOGDEB(("MHExecMultiple: got ipath [%s]\n", data.c_str()));
         } else if (!stringlowercmp("mimetype:", name)) {
             mtype = data;
             LOGDEB(("MHExecMultiple: got mimetype [%s]\n", data.c_str()));
@@ -246,7 +251,7 @@ bool MimeHandlerExecMultiple::next_document()
     if (!ipath.empty()) {
         m_metaData["ipath"] = ipath;
         if (mtype.empty()) {
-            mtype = mimetype(ipath, 0, RclConfig::getMainConfig(), false);
+            mtype = mimetype(ipath, 0, m_config, false);
             if (mtype.empty()) {
                 // mimetype() won't call idFile when there is no file. Do it
                 mtype = idFileMem(m_metaData["content"]);
@@ -275,6 +280,19 @@ bool MimeHandlerExecMultiple::next_document()
         }
     }
 
+    // Charset. For many document types it doesn't matter. For text
+    // and html it does. We supply a default from the
+    // configuration. We should do the text transcoding to utf-8 here
+    // like exec::finaldetails does.
+    if (charset.empty()) {
+	charset = cfgFilterOutputCharset.empty() ? "utf-8" : 
+	    cfgFilterOutputCharset;
+	if (!stringlowercmp("default", charset)) {
+	    charset = m_dfltInputCharset;
+	}
+    }
+    m_metaData["charset"] = charset;
+    
     if (eofnext_received)
         m_havedoc = false;
 
