@@ -79,11 +79,11 @@ public:
     }
 
     ~MboxCache() {}
-    mbhoff_type get_offset(const string& udi, int msgnum)
+    mbhoff_type get_offset(RclConfig *config, const string& udi, int msgnum)
     {
         LOGDEB0(("MboxCache::get_offsets: udi [%s] msgnum %d\n", udi.c_str(),
                  msgnum));
-        if (!ok()) {
+        if (!ok(config)) {
             LOGDEB0(("MboxCache::get_offsets: init failed\n"));
             return -1;
         }
@@ -125,11 +125,11 @@ public:
     }
 
     // Save array of offsets for a given file, designated by Udi
-    void put_offsets(const string& udi, mbhoff_type fsize,
+    void put_offsets(RclConfig *config, const string& udi, mbhoff_type fsize,
                      vector<mbhoff_type>& offs)
     {
         LOGDEB0(("MboxCache::put_offsets: %u offsets\n", offs.size()));
-        if (!ok() || !maybemakedir())
+        if (!ok(config) || !maybemakedir())
             return;
         if (fsize < m_minfsize)
             return;
@@ -161,13 +161,10 @@ public:
     }
 
     // Check state, possibly initialize
-    bool ok() {
+    bool ok(RclConfig *config) {
         if (m_minfsize == -1)
             return false;
         if (!m_ok) {
-            RclConfig *config = RclConfig::getMainConfig();
-            if (config == 0)
-                return false;
             int minmbs = 5;
             config->getConfParam("mboxcacheminmbs", &minmbs);
             if (minmbs < 0) {
@@ -269,9 +266,8 @@ bool MimeHandlerMbox::set_document_file(const string &fn)
     m_quirks = 0;
 
     // Check for location-based quirks:
-    RclConfig *config = RclConfig::getMainConfig();
     string quirks;
-    if (config && config->getConfParam(keyquirks, quirks)) {
+    if (m_config && m_config->getConfParam(keyquirks, quirks)) {
 	if (quirks == "tbird") {
 	    LOGDEB(("MimeHandlerMbox: setting quirks TBIRD\n"));
 	    m_quirks |= MBOXQUIRK_TBIRD;
@@ -350,7 +346,13 @@ static const  char *frompat =
 "[0-2][0-9]:[0-5][0-9](:[0-5][0-9])?"                  // Time, secs optional
     ;
 
+// Extreme thunderbird brokiness. Will sometimes use From lines
+// exactly like: From ^M (From followed by space and eol). We only
+// test for this if QUIRKS_TBIRD is set
+static const char *miniTbirdFrom = "^From $";
+
 static regex_t fromregex;
+static regex_t minifromregex;
 static bool regcompiled;
 
 bool MimeHandlerMbox::next_document()
@@ -373,9 +375,12 @@ bool MimeHandlerMbox::next_document()
     }
     LOGDEB0(("MimeHandlerMbox::next_document: fn %s, msgnum %d mtarg %d \n", 
 	    m_fn.c_str(), m_msgnum, mtarg));
+    if (mtarg == 0)
+	mtarg = -1;
 
     if (!regcompiled) {
 	regcomp(&fromregex, frompat, REG_NOSUB|REG_EXTENDED);
+	regcomp(&minifromregex, miniTbirdFrom, REG_NOSUB|REG_EXTENDED);
 	regcompiled = true;
     }
 
@@ -393,10 +398,12 @@ bool MimeHandlerMbox::next_document()
         LOGDEB0(("MimeHandlerMbox::next_doc: mtarg %d m_udi[%s]\n",
                 mtarg, m_udi.c_str()));
         if (!m_udi.empty() && 
-            (off = mcache.get_offset(m_udi, mtarg)) >= 0 && 
+            (off = mcache.get_offset(m_config, m_udi, mtarg)) >= 0 && 
             fseeko(fp, (off_t)off, SEEK_SET) >= 0 && 
             fgets(line, LL, fp) &&
-            !regexec(&fromregex, line, 0, 0, 0)) {
+            (!regexec(&fromregex, line, 0, 0, 0) || 
+	     ((m_quirks & MBOXQUIRK_TBIRD) && 
+	      !regexec(&minifromregex, line, 0, 0, 0)))	) {
                 LOGDEB0(("MimeHandlerMbox: Cache: From_ Ok\n"));
                 fseeko(fp, (off_t)off, SEEK_SET);
                 m_msgnum = mtarg -1;
@@ -406,97 +413,75 @@ bool MimeHandlerMbox::next_document()
         }
     }
 
-    off_t start, end;
+    off_t message_end = 0;
     bool iseof = false;
     bool hademptyline = true;
     string& msgtxt = m_metaData["content"];
     msgtxt.erase();
-    do  {
-	// Look for next 'From ' Line, start of message. Set start to
-	// line after this
-	line_type line;
-	for (;;) {
-            mbhoff_type off_From = ftello(fp);
-	    if (!fgets(line, LL, fp)) {
-		// Eof hit while looking for 'From ' -> file done. We'd need
-		// another return code here
-		LOGDEB2(("MimeHandlerMbox:next: hit eof while looking for "
-			 "start From_ line\n"));
-		return false;
-	    }
-	    m_lineno++;
-	    int ll;
-	    stripendnl(line, ll);
-	    LOGDEB2(("Start: hadempty %d ll %d Line: [%s]\n", 
-		    hademptyline, ll, line));
-	    if (ll <= 0) {
-		hademptyline = true;
-		continue;
-	    }
-	    // Non empty line. If the previous one was empty, check regex
-	    if (hademptyline) {
-		// Tbird sometimes omits the empty line, so avoid resetting
-		// state (initially true) and hope for the best
-		if (!(m_quirks & MBOXQUIRK_TBIRD))
-		    hademptyline = false;
-		if (!regexec(&fromregex, line, 0, 0, 0)) {
-		    LOGDEB0(("MimeHandlerMbox: msgnum %d, "
-			 "From_ at line %d: [%s]\n", m_msgnum, m_lineno, line));
-		    start = ftello(fp);
-		    m_offsets.push_back(off_From);
-		    m_msgnum++;
-		    break;
-		}
-	    }
+    line_type line;
+    for (;;) {
+	message_end = ftello(fp);
+	if (!fgets(line, LL, fp)) {
+	    LOGDEB2(("MimeHandlerMbox:next: eof\n"));
+	    iseof = true;
+	    m_msgnum++;
+	    break;
 	}
-
-	// Look for next 'From ' line or eof, end of message.
-	for (;;) {
-	    end = ftello(fp);
-	    if (!fgets(line, LL, fp)) {
-		if (ferror(fp) || feof(fp))
-		    iseof = true;
-		break;
-	    }
-	    m_lineno++;
-	    int ll;
-	    stripendnl(line, ll);
-	    LOGDEB2(("End: hadempty %d ll %d Line: [%s]\n", 
-		    hademptyline, ll, line));
-	    if (hademptyline) {
-		if (ll > 0) {
-		    if (!(m_quirks & MBOXQUIRK_TBIRD))
-			hademptyline = false;
-		    if (!regexec(&fromregex, line, 0, 0, 0)) {
-			// Rewind to start of "From " line
-			fseek(fp, end, SEEK_SET);
-			m_lineno--;
-                        hademptyline = true;
+	m_lineno++;
+	int ll;
+	stripendnl(line, ll);
+	LOGDEB2(("mhmbox:next: hadempty %d lineno %d ll %d Line: [%s]\n", 
+		 hademptyline, m_lineno, ll, line));
+	if (hademptyline) {
+	    if (ll > 0) {
+		// Non-empty line with empty line flag set, reset flag
+		// and check regex.
+		if (!(m_quirks & MBOXQUIRK_TBIRD)) {
+		    // Tbird sometimes omits the empty line, so avoid
+		    // resetting state (initially true) and hope for
+		    // the best
+		    hademptyline = false;
+		}
+		if (!regexec(&fromregex, line, 0, 0, 0) || 
+		    ((m_quirks & MBOXQUIRK_TBIRD) && 
+		     !regexec(&minifromregex, line, 0, 0, 0)) ) {
+		    LOGDEB1(("MimeHandlerMbox: msgnum %d, "
+		     "From_ at line %d: [%s]\n", m_msgnum, m_lineno, line));
+		    m_offsets.push_back(message_end);
+		    m_msgnum++;
+		    if ((mtarg <= 0 && m_msgnum > 1) || 
+			(mtarg > 0 && m_msgnum > mtarg)) {
+			// Got message, go do something with it
 			break;
 		    }
-		}
-	    } else if (ll <= 0) {
-		hademptyline = true;
-	    }
-	    if (mtarg <= 0 || m_msgnum == mtarg) {
-		line[ll] = '\n';
-		line[ll+1] = 0;
-		msgtxt += line;
+		    // From_ lines are not part of messages
+		    continue;
+		} 
 	    }
+	} else if (ll <= 0) {
+	    hademptyline = true;
 	}
 
-    } while (mtarg > 0 && m_msgnum < mtarg);
-
-    LOGDEB1(("Message text: [%s]\n", msgtxt.c_str()));
+	if (mtarg <= 0 || m_msgnum == mtarg) {
+	    // Accumulate message lines
+	    line[ll] = '\n';
+	    line[ll+1] = 0;
+	    msgtxt += line;
+	}
+    }
+    LOGDEB2(("Message text length %d\n", msgtxt.size()));
+    LOGDEB2(("Message text: [%s]\n", msgtxt.c_str()));
     char buf[20];
-    sprintf(buf, "%d", m_msgnum);
+    // m_msgnum was incremented when hitting the next From_ or eof, so the data
+    // is for m_msgnum - 1
+    sprintf(buf, "%d", m_msgnum - 1); 
     m_metaData["ipath"] = buf;
     m_metaData["mimetype"] = "message/rfc822";
     if (iseof) {
 	LOGDEB2(("MimeHandlerMbox::next: eof hit\n"));
 	m_havedoc = false;
 	if (!m_udi.empty()) {
-	  mcache.put_offsets(m_udi, m_fsize, m_offsets);
+	    mcache.put_offsets(m_config, m_udi, m_fsize, m_offsets);
 	}
     }
     return msgtxt.empty() ? false : true;
@@ -520,7 +505,9 @@ using namespace std;
 
 static char *thisprog;
 
-static char usage [] =
+static char usage [] = 
+"Test driver for mbox walking function\n"
+"mh_mbox [-m num] mboxfile\n"
 "  \n\n"
 ;
 static void
@@ -530,61 +517,87 @@ Usage(void)
     exit(1);
 }
 static RclConfig *config;
-RclConfig *RclConfig::getMainConfig()
-{
-    return config;
-}
+static int     op_flags;
+#define OPT_MOINS 0x1
+#define OPT_m	  0x2
+//#define OPT_t     0x4
 
 int main(int argc, char **argv)
 {
-  thisprog = argv[0];
-  argc--; argv++;
-
-  while (argc > 0 && **argv == '-') {
-    (*argv)++;
-    if (!(**argv))
-      /* Cas du "adb - core" */
-      Usage();
-    while (**argv)
-      switch (*(*argv)++) {
-      default: Usage();	break;
-      }
+    string msgnum;
+    thisprog = argv[0];
     argc--; argv++;
-  }
 
-  if (argc != 1)
-    Usage();
-  string filename = *argv++;argc--;
-  string reason;
-  config = recollinit(RclInitFlags(0), 0, 0, reason, 0);
-  if (config == 0) {
-      cerr << "init failed " << reason << endl;
-      exit(1);
-  }
-  MimeHandlerMbox mh("text/x-mail");
-  if (!mh.set_document_file(filename)) {
-      cerr << "set_document_file failed" << endl;
-      exit(1);
-  }
-  int docnt = 0;
-  while (mh.has_documents()) {
-      if (!mh.next_document()) {
-	  cerr << "next_document failed" << endl;
-	  exit(1);
-      }
-      map<string, string>::const_iterator it = 
-	mh.get_meta_data().find("content");
-      int size;
-      if (it == mh.get_meta_data().end()) {
-	size = -1;
-      } else {
-	size = it->second.length();
-      }
-      cout << "Doc " << docnt << " size " << size  << endl;
-      docnt++;
-  }
-  cout << docnt << " documents found in " << filename << endl;
-  exit(0);
+    while (argc > 0 && **argv == '-') {
+	(*argv)++;
+	if (!(**argv))
+	    /* Cas du "adb - core" */
+	    Usage();
+	while (**argv)
+	    switch (*(*argv)++) {
+	    case 'm':	op_flags |= OPT_m; if (argc < 2)  Usage();
+		msgnum = *(++argv);
+		argc--; 
+		goto b1;
+//	    case 't':	op_flags |= OPT_t;break;
+	    default: Usage();	break;
+	    }
+    b1: argc--; argv++;
+    }
+
+    if (argc != 1)
+	Usage();
+    string filename = *argv++;argc--;
+    string reason;
+    config = recollinit(RclInitFlags(0), 0, 0, reason, 0);
+    if (config == 0) {
+	cerr << "init failed " << reason << endl;
+	exit(1);
+    }
+    config->setKeyDir(path_getfather(filename));
+    MimeHandlerMbox mh("text/x-mail");
+    if (!mh.set_document_file(filename)) {
+	cerr << "set_document_file failed" << endl;
+	exit(1);
+    }
+    if (!msgnum.empty()) {
+	mh.skip_to_document(msgnum);
+	if (!mh.next_document()) {
+	    cerr << "next_document failed after skipping to " << msgnum << endl;
+	    exit(1);
+	}
+	map<string, string>::const_iterator it = 
+	    mh.get_meta_data().find("content");
+	int size;
+	if (it == mh.get_meta_data().end()) {
+	    size = -1;
+	    cerr << "No content!!" << endl;
+	    exit(1);
+	}
+	cout << "Doc " << msgnum << ":" << endl;
+	cout << it->second << endl;
+	exit(0);
+    }
+
+    int docnt = 0;
+    while (mh.has_documents()) {
+	if (!mh.next_document()) {
+	    cerr << "next_document failed" << endl;
+	    exit(1);
+	}
+	docnt++;
+	map<string, string>::const_iterator it = 
+	    mh.get_meta_data().find("content");
+	int size;
+	if (it == mh.get_meta_data().end()) {
+	    size = -1;
+	} else {
+	    size = it->second.length();
+	}
+	cout << "Doc " << docnt << " size " << size  << endl;
+    }
+    cout << docnt << " documents found in " << filename << endl;
+    exit(0);
 }
 
 
