@@ -28,7 +28,8 @@
  */
 class MimeHandlerUnknown : public RecollFilter {
  public:
-    MimeHandlerUnknown(const string& mt) : RecollFilter(mt) {}
+    MimeHandlerUnknown(RclConfig *cnf, const string& mt) 
+	: RecollFilter(cnf, mt) {}
     virtual ~MimeHandlerUnknown() {}
     virtual bool set_document_string(const string& fn) {
 	RecollFilter::set_document_file(fn);
@@ -45,9 +46,7 @@ class MimeHandlerUnknown : public RecollFilter {
 	m_metaData["mimetype"] = "text/plain";
 	return true;
     }
-    virtual void clear() {
-	RecollFilter::clear(); 
-    }
+    virtual bool is_unknown() {return true;}
 };
 
 #endif /* _MH_UNKNOWN_H_INCLUDED_ */
