@@ -51,27 +51,33 @@ static multimap<string, Dijon::Filter*>  o_handlers;
 
 /** For mime types set as "internal" in mimeconf: 
   * create appropriate handler object. */
-static Dijon::Filter *mhFactory(const string &mime)
+static Dijon::Filter *mhFactory(RclConfig *config, const string &mime)
 {
+    LOGDEB2(("mhFactory(%s)\n", mime.c_str()));
     string lmime(mime);
     stringtolower(lmime);
     if ("text/plain" == lmime) {
-	return new MimeHandlerText(lmime);
+	return new MimeHandlerText(config, lmime);
     } else if ("text/html" == lmime) {
-	return new MimeHandlerHtml(lmime);
+	return new MimeHandlerHtml(config, lmime);
     } else if ("text/x-mail" == lmime) {
-	return new MimeHandlerMbox(lmime);
+	return new MimeHandlerMbox(config, lmime);
     } else if ("message/rfc822" == lmime) {
-	return new MimeHandlerMail(lmime);
+	return new MimeHandlerMail(config, lmime);
     } else if (lmime.find("text/") == 0) {
         // Try to handle unknown text/xx as text/plain. This
         // only happen if the text/xx was defined as "internal" in
         // mimeconf, not at random. For programs, for example this
         // allows indexing and previewing as text/plain (no filter
         // exec) but still opening with a specific editor.
-        return new MimeHandlerText(lmime); 
+        return new MimeHandlerText(config, lmime); 
     } else {
-	return new MimeHandlerUnknown(lmime);
+	// We should not get there. It means that "internal" was set
+	// as a handler in mimeconf for a mime type we actually can't
+	// handle.
+	LOGERR(("mhFactory: mime type [%s] set as internal but unknown\n", 
+		lmime.c_str()));
+	return new MimeHandlerUnknown(config, lmime);
     }
 }
 
@@ -104,8 +110,8 @@ MimeHandlerExec *mhExecFactory(RclConfig *cfg, const string& mtype, string& hs,
 	return 0;
     }
     MimeHandlerExec *h = multiple ? 
-        new MimeHandlerExecMultiple(mtype.c_str()) :
-        new MimeHandlerExec(mtype.c_str());
+        new MimeHandlerExecMultiple(cfg, mtype.c_str()) :
+        new MimeHandlerExec(cfg, mtype.c_str());
     list<string>::iterator it = cmdtoks.begin();
     h->params.push_back(cfg->findFilter(*it++));
     h->params.insert(h->params.end(), it, cmdtoks.end());
@@ -114,17 +120,17 @@ MimeHandlerExec *mhExecFactory(RclConfig *cfg, const string& mtype, string& hs,
     // with newlines and use a ConfSimple
     string value;
     if (attrs.get("charset", value)) 
-        h->cfgCharset = stringtolower((const string&)value);
+        h->cfgFilterOutputCharset = stringtolower((const string&)value);
     if (attrs.get("mimetype", value))
-        h->cfgMtype = stringtolower((const string&)value);
+        h->cfgFilterOutputMtype = stringtolower((const string&)value);
 
-#if 1
+#if 0
     string scmd;
     for (it = h->params.begin(); it != h->params.end(); it++) {
 	scmd += string("[") + *it + "] ";
     }
     LOGDEB(("mhExecFactory:mt [%s] cfgmt [%s] cfgcs [%s] cmd: [%s]\n",
-	    mtype.c_str(), h->cfgMtype.c_str(), h->cfgCharset.c_str(),
+	    mtype.c_str(), h->cfgFilterOutputMtype.c_str(), h->cfgFilterOutputCharset.c_str(),
 	    scmd.c_str()));
 #endif
 
@@ -158,6 +164,7 @@ Dijon::Filter *getMimeHandler(const string &mtype, RclConfig *cfg,
 {
     LOGDEB2(("getMimeHandler: mtype [%s] filtertypes %d\n", 
              mtype.c_str(), filtertypes));
+    Dijon::Filter *h = 0;
 
     // Get handler definition for mime type. We do this even if an
     // appropriate handler object may be in the cache (indexed by mime
@@ -173,35 +180,52 @@ Dijon::Filter *getMimeHandler(const string &mtype, RclConfig *cfg,
         // Do we already have a handler object in the cache ?
         map<string, Dijon::Filter *>::iterator it = o_handlers.find(mtype);
         if (it != o_handlers.end()) {
-            Dijon::Filter *h = it->second;
+            h = it->second;
             o_handlers.erase(it);
             LOGDEB2(("getMimeHandler: found in cache\n"));
-            return h;
+            goto out;
         }
 
 	// Not in cache. Break definition into type and name/command
         // string and instanciate handler object
         string::size_type b1 = hs.find_first_of(" \t");
         string handlertype = hs.substr(0, b1);
+	string cmdstr;
+	if (b1 != string::npos) {
+	    cmdstr = hs.substr(b1);
+            trimstring(cmdstr);
+	}
 	if (!stringlowercmp("internal", handlertype)) {
-	    return mhFactory(mtype);
+	    // If there is a parameter after "internal" it's the mime
+	    // type to use. This is so that we can have bogus mime
+	    // types like text/x-purple-html-log (for ie: specific
+	    // icon) and still use the html filter on them. This is
+	    // partly redundant with the localfields/rclaptg, but
+	    // better and the latter will probably go away at some
+	    // point in the future
+	    LOGDEB2(("handlertype internal, cmdstr [%s]\n", cmdstr.c_str()));
+	    if (!cmdstr.empty())
+		h = mhFactory(cfg, cmdstr);
+	    else 
+		h = mhFactory(cfg, mtype);
+	    goto out;
 	} else if (!stringlowercmp("dll", handlertype)) {
 	} else {
-            string cmdstr = hs.substr(b1);
-            trimstring(cmdstr);
             if (cmdstr.empty()) {
 		LOGERR(("getMimeHandler: bad line for %s: %s\n", 
 			mtype.c_str(), hs.c_str()));
-		return 0;
+		goto out;
 	    }
             if (!stringlowercmp("exec", handlertype)) {
-                return mhExecFactory(cfg, mtype, cmdstr, false);
+                h = mhExecFactory(cfg, mtype, cmdstr, false);
+		goto out;
             } else if (!stringlowercmp("execm", handlertype)) {
-                return mhExecFactory(cfg, mtype, cmdstr, true);
+                h = mhExecFactory(cfg, mtype, cmdstr, true);
+		goto out;
             } else {
 		LOGERR(("getMimeHandler: bad line for %s: %s\n", 
 			mtype.c_str(), hs.c_str()));
-		return 0;
+		goto out;
             }
 	}
     }
@@ -213,22 +237,30 @@ Dijon::Filter *getMimeHandler(const string &mtype, RclConfig *cfg,
     // If the type is an unknown text/xxx, index as text/plain and
     // hope for the best (this wouldn't work too well with text/rtf...)
     if (mtype.find("text/") == 0) {
-        return mhFactory("text/plain");
+        h = mhFactory("text/plain");
+	goto out;
     }
 #endif
 
     // Finally, unhandled files are either ignored or their name and
     // generic metadata is indexed, depending on configuration
-    bool indexunknown = false;
-    cfg->getConfParam("indexallfilenames", &indexunknown);
-    if (indexunknown) {
-	LOGDEB(("getMimeHandler: returning MimeHandlerUnknown\n"));
-	return new MimeHandlerUnknown("application/octet-stream");
-    } else {
-	return 0;
+    {bool indexunknown = false;
+	cfg->getConfParam("indexallfilenames", &indexunknown);
+	if (indexunknown) {
+	    h = new MimeHandlerUnknown(cfg, "application/octet-stream");
+	    goto out;
+	} else {
+	    goto out;
+	}
     }
-}
 
+out:
+    if (h) {
+	string charset = cfg->getDefCharset();
+	h->set_property(Dijon::Filter::DEFAULT_CHARSET, charset);
+    }
+    return h;
+}
 
 /// Can this mime type be interned (according to config) ?
 bool canIntern(const std::string mtype, RclConfig *cfg)
