@@ -30,8 +30,9 @@ class RclConfig;
 
 class RecollFilter : public Dijon::Filter {
 public:
-    RecollFilter(const string& mtype)
-	: Dijon::Filter(mtype), m_forPreview(false), m_havedoc(false)
+    RecollFilter(RclConfig *config, const string& mtype)
+	: Dijon::Filter(mtype), m_config(config), 
+	  m_forPreview(false), m_havedoc(false)
     {}
     virtual ~RecollFilter() {}
     virtual bool set_property(Properties p, const string &v) {
@@ -40,7 +41,7 @@ public:
 	    m_udi = v;
 	    break;
 	case DEFAULT_CHARSET: 
-	    m_defcharset = v;
+	    m_dfltInputCharset = v;
 	    break;
 	case OPERATING_MODE: 
 	    if (!v.empty() && v[0] == 'v') 
@@ -88,13 +89,14 @@ public:
     virtual void clear() {
 	Dijon::Filter::clear();
 	m_forPreview = m_havedoc = false;
-	m_defcharset.clear();
+	m_dfltInputCharset.clear();
 	m_reason.clear();
     }
 
 protected:
+    RclConfig *m_config;
     bool   m_forPreview;
-    string m_defcharset;
+    string m_dfltInputCharset;
     string m_reason;
     bool   m_havedoc;
     string m_udi; // May be set by creator as a hint
