@@ -48,16 +48,12 @@ using namespace std;
 #include "readfile.h"
 #include "smallut.h"
 #include "textsplit.h"
+#include "guiutils.h"
 
 using namespace KIO;
 
 RclConfig *RecollProtocol::o_rclconfig;
 
-RclConfig *RclConfig::getMainConfig()
-{
-    return RecollProtocol::o_rclconfig;
-}
-
 RecollProtocol::RecollProtocol(const QByteArray &pool, const QByteArray &app) 
     : SlaveBase("recoll", pool, app), m_initok(false), m_rcldb(0),
       m_alwaysdir(false)
@@ -77,6 +73,7 @@ RecollProtocol::RecollProtocol(const QByteArray &pool, const QByteArray &app)
 	m_reason = "No db directory in configuration ??";
 	return;
     }
+    rwSettings(false);
 
     m_rcldb = new Rcl::Db(o_rclconfig);
     if (!m_rcldb) {
@@ -120,13 +117,10 @@ bool RecollProtocol::maybeOpenDb(string &reason)
     return true;
 }
 
-// Not sure this is ever used 
+// This is never called afaik
 void RecollProtocol::mimetype(const KUrl &url)
 {
     kDebug() << url << endl;
-    ///////////////////////////////REMOVEME REMOVEME REMOVEME when sure !/////
-    abort();
-    ////////////////////////////////////////////////////////////////////////
     mimeType("text/html");
     finished();
 }
@@ -336,7 +330,7 @@ bool RecollProtocol::doSearch(const QueryDesc& qd)
 	if (sd && clp)
 	    sd->addClause(clp);
     } else {
-	sd = wasaStringToRcl(qs, m_reason);
+	sd = wasaStringToRcl(o_rclconfig, qs, m_reason);
     }
     if (!sd) {
 	m_reason = "Internal Error: cant build search";
@@ -347,6 +341,7 @@ bool RecollProtocol::doSearch(const QueryDesc& qd)
     RefCntr<Rcl::SearchData> sdata(sd);
     sdata->setStemlang("english");
     RefCntr<Rcl::Query>query(new Rcl::Query(m_rcldb));
+    query->setCollapseDuplicates(prefs.collapseDuplicates);
     if (!query->setQuery(sdata)) {
 	m_reason = "Query execute failed. Invalid query or syntax error?";
 	error(KIO::ERR_SLAVE_DEFINED, m_reason.c_str());
