@@ -311,8 +311,6 @@ Doc_getattr(recoll_DocObject *self, char *name)
     case 'f':
 	if (!key.compare(Rcl::Doc::keyfs)) {
 	    value = self->doc->fbytes;
-	} else if (!key.compare(Rcl::Doc::keyfn)) {
-	    value = self->doc->utf8fn;
 	} else if (!key.compare(Rcl::Doc::keyfs)) {
 	    value = self->doc->fbytes;
 	} else if (!key.compare(Rcl::Doc::keyfmt)) {
@@ -351,12 +349,12 @@ Doc_getattr(recoll_DocObject *self, char *name)
 	    value = self->doc->dbytes.empty() ? self->doc->fbytes : 
 		self->doc->dbytes;
 	}
-
 	break;
-    default:
-	value = self->doc->meta[key];
     }
 
+    if (value.empty())
+	value = self->doc->meta[key];
+
     LOGDEB(("Doc_getattr: [%s] (%s) -> [%s]\n",
 	    name, key.c_str(), value.c_str()));
     // Return a python unicode object
@@ -729,20 +727,14 @@ Query_fetchone(recoll_QueryObject* self, PyObject *, PyObject *)
 
     // Move some data from the dedicated fields to the meta array to make 
     // fetching attributes easier. Is this actually needed ? Useful for
-    // url and relevancy rating which are also formatted .
+    // url which is also formatted .
     Rcl::Doc *doc = result->doc;
     printableUrl(rclconfig->getDefCharset(), doc->url, 
 		 doc->meta[Rcl::Doc::keyurl]);
     doc->meta[Rcl::Doc::keytp] = doc->mimetype;
-    doc->meta[Rcl::Doc::keymt] = doc->dmtime.empty() ? 
-	doc->fmtime : doc->dmtime;
     doc->meta[Rcl::Doc::keyipt] = doc->ipath;
     doc->meta[Rcl::Doc::keyfs] = doc->fbytes;
     doc->meta[Rcl::Doc::keyds] = doc->dbytes;
-    char pc[20];
-    sprintf(pc, "%02d %%", doc->pc);
-    doc->meta[Rcl::Doc::keyrr] = pc;
-
     return (PyObject *)result;
 }
 
@@ -1212,11 +1204,6 @@ static PyMethodDef recollMethods[] = {
 };
 
 
-RclConfig *RclConfig::getMainConfig() 
-{
-    return rclconfig;
-}
-
 PyDoc_STRVAR(pyrecoll_doc_string,
 "This is an interface to the Recoll full text indexer.");
 
