@@ -26,17 +26,6 @@ static char rcsid[] = "@(#$Id: advsearch_w.cpp,v 1.21 2008-09-25 06:00:24 dockes
 #include <qframe.h>
 #include <qcheckbox.h>
 #include <qevent.h>
-
-#if (QT_VERSION < 0x040000)
-#include <qcombobox.h>
-#include <qlistbox.h>
-#define Q34EVOVERRIDE QEvent::AccelOverride
-#else
-#include <q3combobox.h>
-#include <q3listbox.h>
-#define Q34EVOVERRIDE QEvent::ShortcutOverride
-#endif
-
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
@@ -73,9 +62,8 @@ static map<QString,QString> cat_rtranslations;
 void AdvSearch::init()
 {
     (void)new HelpClient(this);
-    HelpClient::installMap(this->name(), "RCL.SEARCH.COMPLEX");
-
-    this->installEventFilter(this);
+    HelpClient::installMap((const char *)objectName().toUtf8(), 
+			   "RCL.SEARCH.COMPLEX");
 
     // signals and slots connections
     connect(delFiltypPB, SIGNAL(clicked()), this, SLOT(delFiltypPB_clicked()));
@@ -97,8 +85,8 @@ void AdvSearch::init()
     connect(addClausePB, SIGNAL(clicked()), this, SLOT(addClause()));
     connect(delClausePB, SIGNAL(clicked()), this, SLOT(delClause()));
 
-    conjunctCMB->insertItem(tr("All clauses"));
-    conjunctCMB->insertItem(tr("Any clause"));
+    conjunctCMB->insertItem(1, tr("All clauses"));
+    conjunctCMB->insertItem(2, tr("Any clause"));
 
     // Create preconfigured clauses
     for (unsigned int i = 0; i < iclausescnt; i++) {
@@ -127,7 +115,7 @@ void AdvSearch::init()
     restrictCtCB->setChecked(m_ignByCats);
     fillFileTypes();
 
-    subtreeCMB->insertStringList(prefs.asearchSubdirHist);
+    subtreeCMB->insertItems(0, prefs.asearchSubdirHist);
     subtreeCMB->setEditText("");
 
     // The clauseline frame is needed to force designer to accept a
@@ -156,26 +144,13 @@ void AdvSearch::init()
     cat_rtranslations[tr("other")] = QString::fromUtf8("other"); 
 }
 
-bool AdvSearch::eventFilter(QObject *, QEvent *event)
-{
-    //    LOGDEB(("AdvSearch::eventFilter. Type %d\n", (int)event->type()));
-    if (event->type() == QEvent::KeyPress || event->type() == Q34EVOVERRIDE) {
-	QKeyEvent *ke = static_cast<QKeyEvent *>(event);
-	if (ke->key() == Qt::Key_Q && (ke->state() & Qt::ControlButton)) {
-	    recollNeedsExit = 1;
-	    return true;
-	}
-    }
-    return false;
-}
-
 void AdvSearch::saveCnf()
 {
     // Save my state
     prefs.advSearchClauses.clear(); 
     for (std::list<SearchClauseW *>::iterator cit = m_clauseWins.begin();
 	 cit != m_clauseWins.end(); cit++) {
-	prefs.advSearchClauses.push_back((*cit)->sTpCMB->currentItem());
+	prefs.advSearchClauses.push_back((*cit)->sTpCMB->currentIndex());
     }
 }
 
@@ -185,17 +160,9 @@ bool AdvSearch::close()
     return QWidget::close();
 }
 
-#if (QT_VERSION >= 0x040000)
-#define QListBoxItem Q3ListBoxItem
-#define clauseVBox Ui::AdvSearchBase::clauseVBox
-#define AdvSearchBaseLayout Ui::AdvSearchBase::AdvSearchBaseLayout
-#endif
-
 void AdvSearch::delAFiltypPB_clicked()
 {
-    for (unsigned int i = 0; i < yesFiltypsLB->count();i++) {
-	yesFiltypsLB->setSelected(i, true);
-    }
+    yesFiltypsLB->selectAll();
     delFiltypPB_clicked();
 }
 
@@ -234,60 +201,43 @@ void AdvSearch::delClause()
 // Move selected file types from the searched to the ignored box
 void AdvSearch::delFiltypPB_clicked()
 {
-    list<int> trl;
-    QStringList moved;
-    for (unsigned int i = 0; i < yesFiltypsLB->count();i++) {
-	QListBoxItem *item = yesFiltypsLB->item(i);
-	if (item && item->isSelected()) {
-	    moved.push_back(item->text());
-	    trl.push_front(i);
-	}
-    }
-    if (!moved.empty()) {
-	noFiltypsLB->insertStringList(moved);
-	for (list<int>::iterator it = trl.begin();it != trl.end(); it++)
-	    yesFiltypsLB->removeItem(*it);
-    }
-    yesFiltypsLB->sort();
-    noFiltypsLB->sort();
-    m_ignTypes.clear();
-    for (unsigned int i = 0; i < noFiltypsLB->count();i++) {
-	QListBoxItem *item = noFiltypsLB->item(i);
-	m_ignTypes.append(item->text());
+    QList<QListWidgetItem *> items = yesFiltypsLB->selectedItems();
+    for (QList<QListWidgetItem *>::iterator it = items.begin(); 
+	 it != items.end(); it++) {
+	int row = yesFiltypsLB->row(*it);
+	QListWidgetItem *item = yesFiltypsLB->takeItem(row);
+	noFiltypsLB->insertItem(0, item);
     }
+    guiListsToIgnTypes();
 }
 
 // Move selected file types from the ignored to the searched box
 void AdvSearch::addFiltypPB_clicked()
 {
-    list<int> trl;
-    QStringList moved;
-    for (unsigned int i = 0; i < noFiltypsLB->count(); i++) {
-	QListBoxItem *item = noFiltypsLB->item(i);
-	if (item && item->isSelected()) {
-	    moved.push_back(item->text());
-	    trl.push_front(i);
-	}
+    QList<QListWidgetItem *> items = noFiltypsLB->selectedItems();
+    for (QList<QListWidgetItem *>::iterator it = items.begin(); 
+	 it != items.end(); it++) {
+	int row = noFiltypsLB->row(*it);
+	QListWidgetItem *item = noFiltypsLB->takeItem(row);
+	yesFiltypsLB->insertItem(0, item);
     }
-    if (!moved.empty()) {
-	yesFiltypsLB->insertStringList(moved);
-	for (list<int>::iterator it = trl.begin();it != trl.end(); it++)
-	    noFiltypsLB->removeItem(*it);
-    }
-    yesFiltypsLB->sort();
-    noFiltypsLB->sort();
+    guiListsToIgnTypes();
+ }
+
+// Compute list of ignored mime type from widget lists
+void AdvSearch::guiListsToIgnTypes()
+{
+    yesFiltypsLB->sortItems();
+    noFiltypsLB->sortItems();
     m_ignTypes.clear();
-    for (unsigned int i = 0; i < noFiltypsLB->count();i++) {
-	QListBoxItem *item = noFiltypsLB->item(i);
+    for (int i = 0; i < noFiltypsLB->count();i++) {
+	QListWidgetItem *item = noFiltypsLB->item(i);
 	m_ignTypes.append(item->text());
     }
 }
-
 void AdvSearch::addAFiltypPB_clicked()
 {
-    for (unsigned int i = 0; i < noFiltypsLB->count();i++) {
-	noFiltypsLB->setSelected(i, true);
-    }
+    noFiltypsLB->selectAll();
     addFiltypPB_clicked();
 }
 
@@ -317,7 +267,7 @@ void AdvSearch::fillFileTypes()
 {
     noFiltypsLB->clear();
     yesFiltypsLB->clear();
-    noFiltypsLB->insertStringList(m_ignTypes); 
+    noFiltypsLB->insertItems(0, m_ignTypes); 
 
     QStringList ql;
     if (m_ignByCats == false) {
@@ -325,7 +275,7 @@ void AdvSearch::fillFileTypes()
 	for (list<string>::iterator it = types.begin(); 
 	     it != types.end(); it++) {
 	    QString qs = QString::fromUtf8(it->c_str());
-	    if (m_ignTypes.findIndex(qs) < 0)
+	    if (m_ignTypes.indexOf(qs) < 0)
 		ql.append(qs);
 	}
     } else {
@@ -341,11 +291,11 @@ void AdvSearch::fillFileTypes()
 	    } else {
 		cat = QString::fromUtf8(it->c_str());
 	    } 
-	    if (m_ignTypes.findIndex(cat) < 0)
+	    if (m_ignTypes.indexOf(cat) < 0)
 		ql.append(cat);
 	}
     }
-    yesFiltypsLB->insertStringList(ql);
+    yesFiltypsLB->insertItems(0, ql);
 }
 
 // Save current list of ignored file types to prefs
@@ -359,7 +309,7 @@ void AdvSearch::saveFileTypes()
 using namespace Rcl;
 void AdvSearch::runSearch()
 {
-    RefCntr<SearchData> sdata(new SearchData(conjunctCMB->currentItem() == 0 ?
+    RefCntr<SearchData> sdata(new SearchData(conjunctCMB->currentIndex() == 0 ?
 					     SCLT_AND : SCLT_OR));
     bool hasclause = false;
 
@@ -374,17 +324,17 @@ void AdvSearch::runSearch()
     if (!hasclause)
         return;
 
-    if (restrictFtCB->isOn() && noFiltypsLB->count() > 0) {
-	for (unsigned int i = 0; i < yesFiltypsLB->count(); i++) {
-	    if (restrictCtCB->isOn()) {
+    if (restrictFtCB->isChecked() && noFiltypsLB->count() > 0) {
+	for (int i = 0; i < yesFiltypsLB->count(); i++) {
+	    if (restrictCtCB->isChecked()) {
 		QString qcat = yesFiltypsLB->item(i)->text();
 		map<QString,QString>::const_iterator qit;
 		string cat;
 		if ((qit = cat_rtranslations.find(qcat)) != 
 		    cat_rtranslations.end()) {
-		    cat = (const char *)qit->second.utf8();
+		    cat = (const char *)qit->second.toUtf8();
 		} else {
-		    cat = (const char *)qcat.utf8();
+		    cat = (const char *)qcat.toUtf8();
 		}
 		list<string> types;
 		rclconfig->getMimeCatTypes(cat, types);
@@ -394,19 +344,19 @@ void AdvSearch::runSearch()
 		}
 	    } else {
 		sdata->addFiletype((const char *)
-				   yesFiltypsLB->item(i)->text().utf8());
+				   yesFiltypsLB->item(i)->text().toUtf8());
 	    }
 	}
     }
 
     if (!subtreeCMB->currentText().isEmpty()) {
 	QString current = subtreeCMB->currentText();
-	sdata->setTopdir((const char*)subtreeCMB->currentText().utf8());
+	sdata->setTopdir((const char*)subtreeCMB->currentText().toUtf8());
 	// Keep history list clean and sorted. Maybe there would be a
 	// simpler way to do this
 	list<QString> entries;
 	for (int i = 0; i < subtreeCMB->count(); i++) {
-	    entries.push_back(subtreeCMB->text(i));
+	    entries.push_back(subtreeCMB->itemText(i));
 	}
 	entries.push_back(subtreeCMB->currentText());
 	entries.sort();
@@ -414,12 +364,12 @@ void AdvSearch::runSearch()
 	subtreeCMB->clear();
 	for (list<QString>::iterator it = entries.begin(); 
 	     it != entries.end(); it++) {
-	    subtreeCMB->insertItem(*it);
+	    subtreeCMB->addItem(*it);
 	}
-	subtreeCMB->setCurrentText(current);
+	subtreeCMB->setCurrentIndex(subtreeCMB->findText(current));
 	prefs.asearchSubdirHist.clear();
 	for (int index = 0; index < subtreeCMB->count(); index++)
-	    prefs.asearchSubdirHist.push_back(subtreeCMB->text(index));
+	    prefs.asearchSubdirHist.push_back(subtreeCMB->itemText(index));
     }
     saveCnf();
     
