@@ -43,19 +43,15 @@
 #include <qstring.h>
 #include <qstringlist.h>
 
+#include "dynconf.h"
+extern RclDynConf *g_dynconf;
+
 #ifndef NO_NAMESPACES
 using std::string;
 using std::list;
 using std::vector;
 #endif
 
-/** Retrieve configured stemming languages */
-bool getStemLangs(list<string>& langs);
-
-/** Start a browser on the help document */
-extern bool startHelpBrowser(const string& url = "");
-
-
 /** Holder for preferences (gets saved to user Qt prefs) */
 class PrefsPack {
  public:
@@ -78,14 +74,16 @@ class PrefsPack {
     int pvheight;
     int ssearchTyp;
     bool    useDesktopOpen; // typically xdg-open, instead of mimeview settings
-    bool    keepSort; // remember sort status between invocations
+    bool    keepSort;   // Remember sort status between invocations
     bool    sortActive; // Remembered sort state.
+    bool    sortDesc;  // ..
     bool queryBuildAbstract;
     bool queryReplaceAbstract;
     bool startWithAdvSearchOpen;
-    bool startWithSortToolOpen;
     bool previewHtml;
     bool collapseDuplicates;
+    bool showResultsAsTable;
+
     // Extra query indexes. This are stored in the history file, not qt prefs
     list<string> allExtraDbs;
     list<string> activeExtraDbs;
@@ -104,23 +102,26 @@ class PrefsPack {
     QString autoSuffs;
     bool    autoSuffsEnable;
 
+    QStringList restableFields;
+    vector<int> restableColWidths;
+
     // Synthetized abstract length and word context size
     int syntAbsLen;
     int syntAbsCtx;
 
-    // Sort specs (sort_w.cpp knows how to deal with the values
-    int sortDepth;
-    int sortSpec;
-
     // Remembered term match mode
     int termMatchType;
 
-    // Program version that wrote this
+    // Program version that wrote this. Not used for now, in prevision
+    // of the case where we might need an incompatible change
     int rclVersion;
 
     // Advanced search window clause list state
     vector<int> advSearchClauses;
 
+    // Default paragraph format for result list
+    static const char *dfltResListFormat;
+
     PrefsPack() :
 	respagesize(8), 
 	reslistfontsize(10),
@@ -128,22 +129,10 @@ class PrefsPack {
 	queryBuildAbstract(true),
 	queryReplaceAbstract(false),
 	startWithAdvSearchOpen(false),
-	startWithSortToolOpen(false),
 	termMatchType(0),
 	rclVersion(1009)
 	    {
 	    }
-    static const char *getDfltResListFormat() {
-	return 	"<img src=\"%I\" align=\"left\">"
-	"%R %S %L &nbsp;&nbsp;<b>%T</b><br>"
-	"%M&nbsp;%D&nbsp;&nbsp;&nbsp;<i>%U</i>&nbsp;%i<br>"
-	"%A %K";
-    }
-    static const char *getV18DfltResListFormat() {
-	return 	"%R %S %L &nbsp;&nbsp;<b>%T</b><br>"
-	"%M&nbsp;%D&nbsp;&nbsp;&nbsp;<i>%U</i><br>"
-	"%A %K";
-    }
 };
 
 /** Global preferences record */
