@@ -23,7 +23,6 @@
 #include "preview_w.h"
 #include "recoll.h"
 #include "advsearch_w.h"
-#include "sort_w.h"
 #include "uiprefs_w.h"
 #include "rcldb.h"
 #include "searchdata.h"
@@ -32,47 +31,31 @@
 #include "pathut.h"
 
 class ExecCmd;
-
-#if QT_VERSION < 0x040000
-#include "rclmain.h"
-#else
-#include "ui_rclmain.h"
-#endif
-
-//MOC_SKIP_BEGIN
-#if QT_VERSION < 0x040000
-class DummyRclMainBase : public RclMainBase
-{
- public: DummyRclMainBase(QWidget* parent = 0) : RclMainBase(parent) {}
-};
-#define RCLMAINPARENT QWidget
-#else
-class DummyRclMainBase : public QMainWindow, public Ui::RclMainBase
-{
-public: DummyRclMainBase(QWidget *parent) :QMainWindow(parent){setupUi(this);}
-#define RCLMAINPARENT QMainWindow
-};
-#endif
-//MOC_SKIP_END
-
 class Preview;
+class ResTable;
+
+#include "ui_rclmain.h"
+
 namespace confgui {
-class ConfIndexW;
+    class ConfIndexW;
 }
+
 using confgui::ConfIndexW;
 
-class RclMain : public DummyRclMainBase
+class RclMain : public QMainWindow, public Ui::RclMainBase
 {
     Q_OBJECT
 
 public:
-    RclMain(RCLMAINPARENT * parent = 0) 
-	: DummyRclMainBase(parent) 
+    RclMain(QWidget * parent = 0) 
+	: QMainWindow(parent), m_sortspecnochange(false)
     {
+	setupUi(this);
 	init();
     }
     ~RclMain() {}
     virtual bool eventFilter(QObject *target, QEvent *event);
+    QString getQueryDescription();
 
 public slots:
     virtual bool close();
@@ -82,7 +65,6 @@ public slots:
     virtual void startSearch(RefCntr<Rcl::SearchData> sdata);
     virtual void previewClosed(Preview *w);
     virtual void showAdvSearchDialog();
-    virtual void showSortDialog();
     virtual void showSpellDialog();
     virtual void showAboutDialog();
     virtual void showMissingHelpers();
@@ -95,29 +77,37 @@ public slots:
     virtual void setUIPrefs();
     virtual void enableNextPage(bool);
     virtual void enablePrevPage(bool);
-    virtual void docExpand(int);
-    virtual void ssearchAddTerm(QString);
-    virtual void startPreview(int docnum, int);
-    virtual void startPreview(Rcl::Doc doc);
-    virtual void startNativeViewer(int docnum);
-    virtual void startNativeViewer(Rcl::Doc doc);
-    virtual void saveDocToFile(int docnum);
+    virtual void docExpand(Rcl::Doc);
+    virtual void startPreview(int docnum, Rcl::Doc doc, int keymods);
+    virtual void startPreview(Rcl::Doc);
+    virtual void startNativeViewer(Rcl::Doc);
+    virtual void saveDocToFile(Rcl::Doc);
     virtual void previewNextInTab(Preview *, int sid, int docnum);
     virtual void previewPrevInTab(Preview *, int sid, int docnum);
     virtual void previewExposed(Preview *, int sid, int docnum);
     virtual void resetSearch();
     virtual void eraseDocHistory();
-    // Callback for setting the stemming language through the prefs menu
-    virtual void setStemLang(int id);
-    // Prefs menu about to show, set the checked lang entry
+    virtual void eraseSearchHistory();
+    virtual void setStemLang(QAction *id);
     virtual void adjustPrefsMenu();
     virtual void catgFilter(int);
     virtual void initDbOpen();
     virtual void toggleFullScreen();
     virtual void focusToSearch();
+    virtual void on_actionSortByDateAsc_toggled(bool on);
+    virtual void on_actionSortByDateDesc_toggled(bool on);
+    virtual void on_actionShowResultsAsTable_toggled(bool on);
+    virtual void onResTableSortBy(DocSeqSortSpec);
+    virtual void resultCount(int);
+    virtual void showQueryDetails();
 
 signals:
+    void docSourceChanged(RefCntr<DocSequence>);
     void stemLangChanged(const QString& lang);
+    void sortDataChanged(DocSeqSortSpec);
+    void filtDataChanged(DocSeqFiltSpec);
+    void applyFiltSortData();
+    void searchReset();
 
 protected:
     virtual void closeEvent( QCloseEvent * );
@@ -125,24 +115,29 @@ protected:
 private:
     Preview        *curPreview;
     AdvSearch      *asearchform;
-    SortForm       *sortform;
     UIPrefsDialog  *uiprefs;
     ConfIndexW     *indexConfig;
     SpellW         *spellform;
     QTimer         *periodictimer;
+    ResTable       *restable;
 
     vector<TempFile>  m_tempfiles;
     vector<ExecCmd*>  m_viewers;
-    map<QString, int> m_stemLangToId;
+    map<QString, QAction*> m_stemLangToId;
     vector<string>    m_catgbutvec;
-    int               m_idNoStem;
-    int               m_idAllStem;
+    QAction *         m_idNoStem;
+    QAction *         m_idAllStem;
     bool              m_idxStatusAck; // Did we act on last status?
-
+    DocSeqFiltSpec    m_filtspec;
+    bool              m_sortspecnochange;
+    DocSeqSortSpec    m_sortspec;
+    RefCntr<DocSequence> m_source;
+    
     virtual void init();
     virtual void previewPrevOrNextInTab(Preview *, int sid, int docnum, 
 					bool next);
     virtual void setStemLang(const QString& lang);
+    virtual void onSortCtlChanged();
 };
 
 #endif // RCLMAIN_W_H
