@@ -22,18 +22,19 @@
 #include "rclconfig.h"
 #include "rcldb.h"
 #include "idxthread.h"
-#include "dynconf.h"
 
 // Misc declarations in need of sharing between the UI files
 
 // Open the database if needed. We now force a close/open by default
 extern bool maybeOpenDb(std::string &reason, bool force = true);
 
+/** Retrieve configured stemming languages */
+bool getStemLangs(list<string>& langs);
+
 extern RclConfig *rclconfig;
 extern Rcl::Db *rcldb;
 extern int recollNeedsExit;
 extern int startIndexingAfterConfig; // 1st startup
-extern RclDynConf *g_dynconf;
 extern void startManual(const string& helpindex);
 
 #ifdef RCL_USE_ASPELL
