@@ -3,22 +3,15 @@
 /* @(#$Id: reslist.h,v 1.17 2008-12-16 14:20:10 dockes Exp $  (C) 2005 J.F.Dockes */
 
 #include <list>
+#include <utility>
 
 #ifndef NO_NAMESPACES
 using std::list;
+using std::pair;
 #endif
 
-#if (QT_VERSION < 0x040000)
 #include <qtextbrowser.h>
-class QPopupMenu;
-#define RCLPOPUP QPopupMenu
-#define QTEXTBROWSER QTextBrowser
-#else
-#include <q3textbrowser.h>
-class Q3PopupMenu;
-#define RCLPOPUP Q3PopupMenu
-#define QTEXTBROWSER Q3TextBrowser
-#endif
+#include <QTextCursor>
 
 #include "docseq.h"
 #include "sortseq.h"
@@ -29,6 +22,7 @@ class Q3PopupMenu;
 
 class ResList;
 class QtGuiResListPager;
+class QMenu;
 
 /**
  * Display a list of document records. The data can be out of the history 
@@ -39,7 +33,7 @@ class QtGuiResListPager;
  * engine, and do it instead on the index output, which duplicates code and 
  * may be sometimes slower.
  */
-class ResList : public QTEXTBROWSER
+class ResList : public QTextBrowser
 {
     Q_OBJECT;
 
@@ -48,24 +42,18 @@ class ResList : public QTEXTBROWSER
     ResList(QWidget* parent = 0, const char* name = 0);
     virtual ~ResList();
     
-    // Return document for given docnum. We act as an intermediary to
-    // the docseq here. This has also the side-effect of making the
-    // entry current (visible and highlighted), and only work if the
-    // num is inside the current page or its immediate neighbours.
+    // Return document for given docnum. We mostly act as an
+    // intermediary to the docseq here, but this has also the
+    // side-effect of making the entry current (visible and
+    // highlighted), and only works if the num is inside the current
+    // page or its immediate neighbours.
     bool getDoc(int docnum, Rcl::Doc &);
-
-    QString getDescription(); // Printable actual query performed on db
-    int getResCnt(); // Return total result list size
-    void setDocSource(RefCntr<DocSequence> ndocsource);
     bool displayingHistory();
-    bool getTerms(vector<string>& terms, 
-		  vector<vector<string> >& groups, vector<int>& gslks);
-    list<string> expand(Rcl::Doc& doc);
     int listId() const {return m_listId;}
 
  public slots:
+    virtual void setDocSource(RefCntr<DocSequence> nsource);
     virtual void resetList();     // Erase current list
-    virtual void doubleClicked(int, int);
     virtual void resPageUpOrBack(); // Page up pressed
     virtual void resPageDownOrNext(); // Page down pressed
     virtual void resultPageBack(); // Previous page of results
@@ -82,66 +70,58 @@ class ResList : public QTEXTBROWSER
     virtual void menuOpenParent();
     virtual void previewExposed(int);
     virtual void append(const QString &text);
-    // Only used for qt ver >=4 but seems we cant undef it
-    virtual void selecChanged();
-    virtual void setDocSource();
+    virtual void readDocSource();
     virtual void setSortParams(DocSeqSortSpec spec);
     virtual void setFilterParams(const DocSeqFiltSpec &spec);
     virtual void highlighted(const QString& link);
-
+    virtual void createPopupMenu(const QPoint& pos);
+	
  signals:
     void nextPageAvailable(bool);
     void prevPageAvailable(bool);
-    void docEditClicked(int);
-    void docPreviewClicked(int, int);
-    void docSaveToFileClicked(int);
+    void docEditClicked(Rcl::Doc);
+    void docPreviewClicked(int, Rcl::Doc, int);
+    void docSaveToFileClicked(Rcl::Doc);
     void previewRequested(Rcl::Doc);
     void editRequested(Rcl::Doc);
     void headerClicked();
-    void docExpand(int);
+    void docExpand(Rcl::Doc);
     void wordSelect(QString);
     void linkClicked(const QString&, int); // See emitLinkClicked()
+    void hasResults(int);
 
  protected:
     void keyPressEvent(QKeyEvent *e);
-    void contentsMouseReleaseEvent(QMouseEvent *e);
+    void mouseReleaseEvent(QMouseEvent *e);
+    void mouseDoubleClickEvent(QMouseEvent*);
 
  protected slots:
     virtual void languageChange();
-    virtual void linkWasClicked(const QString &, int);
-    virtual void showQueryDetails();
+    virtual void linkWasClicked(const QUrl &);
 
  private:
-    QtGuiResListPager           *m_pager;
-    // Raw doc source
-    RefCntr<DocSequence>  m_baseDocSource;
-    // Possibly filtered/sorted docsource (the one displayed)
-    RefCntr<DocSequence>  m_docSource;
-    // Current sort and filtering parameters
-    DocSeqSortSpec        m_sortspecs;
-    DocSeqFiltSpec        m_filtspecs;
-    // Docs for current page
-    std::vector<Rcl::Doc> m_curDocs;
+    QtGuiResListPager  *m_pager;
+    RefCntr<DocSequence> m_source;
 
     // Translate from textedit paragraph number to relative
     // docnum. Built while we insert text into the qtextedit
     std::map<int,int>  m_pageParaToReldocnums;
+
     int                m_popDoc; // Docnum for the popup menu.
     int                m_curPvDoc;// Docnum for current preview
     int                m_lstClckMod; // Last click modifier. 
     list<int>          m_selDocs;
-    int                m_listId;
-
+    int                m_listId; // query Id for matching with preview windows
     
     virtual int docnumfromparnum(int);
-    virtual int parnumfromdocnum(int);
+    virtual pair<int,int> parnumfromdocnum(int);
 
     // Don't know why this is necessary but it is
     void emitLinkClicked(const QString &s) {
 	emit linkClicked(s, m_lstClckMod);
     };
-    virtual RCLPOPUP *createPopupMenu(const QPoint& pos);
     static int newListId();
+    void resetView();
 };
 
 
