@@ -40,12 +40,16 @@ static char rcsid[] = "@(#$Id: ssearch_w.cpp,v 1.26 2008-12-05 11:09:31 dockes E
 void SSearch::init()
 {
     // See enum above and keep in order !
-    searchTypCMB->insertItem(tr("Any term"));
-    searchTypCMB->insertItem(tr("All terms"));
-    searchTypCMB->insertItem(tr("File name"));
-    searchTypCMB->insertItem(tr("Query language"));
+    searchTypCMB->addItem(tr("Any term"));
+    searchTypCMB->addItem(tr("All terms"));
+    searchTypCMB->addItem(tr("File name"));
+    searchTypCMB->addItem(tr("Query language"));
     
-    queryText->insertStringList(prefs.ssearchHistory);
+    // We'd like to use QComboBox::InsertAtTop but it doesn't do lru
+    // (existing item stays at its place instead of jumping at top)
+    queryText->setInsertPolicy(QComboBox::NoInsert);
+
+    queryText->addItems(prefs.ssearchHistory);
     queryText->setEditText("");
     connect(queryText->lineEdit(), SIGNAL(returnPressed()),
 	    this, SLOT(startSimpleSearch()));
@@ -56,11 +60,7 @@ void SSearch::init()
     connect(searchPB, SIGNAL(clicked()), this, SLOT(startSimpleSearch()));
     connect(searchTypCMB, SIGNAL(activated(int)), this, SLOT(searchTypeChanged(int)));
 
-#if QT_VERSION >= 0x040000
     queryText->installEventFilter(this);
-#else
-    queryText->lineEdit()->installEventFilter(this);
-#endif
     m_escape = false;
 }
 
@@ -81,14 +81,16 @@ void SSearch::searchTypeChanged(int typ)
     LOGDEB(("Search type now %d\n", typ));
     // Adjust context help
     if (typ == SST_LANG)
-	HelpClient::installMap(this->name(), "RCL.SEARCH.LANG");
+	HelpClient::installMap((const char *)this->objectName().toUtf8(), 
+			       "RCL.SEARCH.LANG");
     else 
-	HelpClient::installMap(this->name(), "RCL.SEARCH.SIMPLE");
+	HelpClient::installMap((const char *)this->objectName().toUtf8(), 
+			       "RCL.SEARCH.SIMPLE");
 
     // Also fix tooltips
     switch (typ) {
     case SST_LANG:
-        QToolTip::add(queryText,
+        queryText->setToolTip(tr(
 "Enter query language expression. Cheat sheet:<br>\n"
 "<i>term1 term2</i> : 'term1' and 'term2' in any field.<br>\n"
 "<i>field:term1</i> : 'term1' in field 'field'.<br>\n"
@@ -101,16 +103,17 @@ void SSearch::searchTypeChanged(int typ)
 "<i>\"term1 term2\"</i> : phrase (must occur exactly). Possible modifiers:<br>\n"
 "<i>\"term1 term2\"p</i> : unordered proximity search with default distance.<br>\n"
 "Use <b>Show Query</b> link when in doubt about result and see manual (&lt;F1>) for more detail.\n"
-            );
+				  ));
         break;
     case SST_FNM:
-        QToolTip::add(queryText, "Enter file name wildcard expression.");
+        queryText->setToolTip(tr("Enter file name wildcard expression."));
         break;
     case SST_ANY:
     case SST_ALL:
     default:
-        QToolTip::add(queryText, 
-    "Enter search terms here. Type ESC SPC for completions of current term.");
+        queryText->setToolTip(tr(
+      "Enter search terms here. Type ESC SPC for completions of current term."
+				  ));
     }
 }
 
@@ -119,27 +122,30 @@ void SSearch::startSimpleSearch()
     if (queryText->currentText().length() == 0)
 	return;
 
-    string u8 = (const char *)queryText->currentText().utf8();
+    string u8 = (const char *)queryText->currentText().toUtf8();
     LOGDEB(("SSearch::startSimpleSearch: [%s]\n", u8.c_str()));
 
     trimstring(u8);
     if (u8.length() == 0)
 	return;
 
-    SSearchType tp = (SSearchType)searchTypCMB->currentItem();
+    SSearchType tp = (SSearchType)searchTypCMB->currentIndex();
     Rcl::SearchData *sdata = 0;
 
     if (tp == SST_LANG) {
 	string reason;
         if (prefs.autoSuffsEnable)
-            sdata = wasaStringToRcl(u8, reason, (const char *)prefs.autoSuffs.utf8());
+            sdata = wasaStringToRcl(rclconfig, u8, reason, (const char *)prefs.autoSuffs.toUtf8());
         else
-            sdata = wasaStringToRcl(u8, reason);
+            sdata = wasaStringToRcl(rclconfig, u8, reason);
 	if (sdata == 0) {
 	    QMessageBox::warning(0, "Recoll", tr("Bad query string") +
 				 QString::fromAscii(reason.c_str()));
 	    return;
 	}
+	if (prefs.ssearchAutoPhrase) {
+	    sdata->maybeAddAutoPhrase();
+	}
     } else {
 	sdata = new Rcl::SearchData(Rcl::SCLT_OR);
 	if (sdata == 0) {
@@ -184,42 +190,23 @@ void SSearch::startSimpleSearch()
 
     // Search terms history
 
-    // Need to remove any previous occurence of the search entry from
-    // the listbox list, The qt listbox doesn't do lru correctly (if
-    // already in the list the new entry would remain at it's place,
-    // not jump at the top as it should
-    LOGDEB3(("Querytext list count %d\n", queryText->count()));
-    // Have to save current text, this will change while we clean up the list
+    // We want to have the new text at the top and any older identical
+    // entry to be erased. There is no standard qt policy to do this ? 
+    // So do it by hand.
     QString txt = queryText->currentText();
-    bool changed;
-    do {
-	changed = false;
-	for (int index = 0; index < queryText->count(); index++) {
-	    LOGDEB3(("Querytext[%d] = [%s]\n", index,
-		    (const char *)(queryText->text(index).utf8())));
-	    if (queryText->text(index).length() == 0 || 
-		QString::compare(queryText->text(index), txt) == 0) {
-		LOGDEB3(("Querytext removing at %d [%s] [%s]\n", index,
-			(const char *)(queryText->text(index).utf8()),
-			(const char *)(txt.utf8())));
-		queryText->removeItem(index);
-		changed = true;
-		break;
-	    }
-	}
-    } while (changed);
-    // The combobox is set for no insertion, insert here:
-    queryText->insertItem(txt, 0);
-    queryText->setCurrentItem(0);
+    int index = queryText->findText(txt);
+    if (index >= 0) 
+	queryText->removeItem(index);
+    queryText->insertItem(0, txt);
+    queryText->setCurrentIndex(0);
 
     // Save the current state of the listbox list to the prefs (will
     // go to disk)
     prefs.ssearchHistory.clear();
     for (int index = 0; index < queryText->count(); index++) {
-	prefs.ssearchHistory.push_back(queryText->text(index));
+	prefs.ssearchHistory.push_back(queryText->itemText(index));
     }
 
-
     RefCntr<Rcl::SearchData> rsdata(sdata);
     emit startSearch(rsdata);
 }
@@ -234,9 +221,37 @@ bool SSearch::hasSearchString()
     return !queryText->lineEdit()->text().isEmpty();
 }
 
+// Add term to simple search. Term comes out of double-click in
+// reslist or preview. 
+// It would probably be better to cleanup in preview.ui.h and
+// reslist.cpp and do the proper html stuff in the latter case
+// (which is different because it format is explicit richtext
+// instead of auto as for preview, needed because it's built by
+// fragments?).
+static const char* punct = " \t()<>\"'[]{}!^*.,:;\n\r";
+void SSearch::addTerm(QString term)
+{
+    LOGDEB(("SSearch::AddTerm: [%s]\n", (const char *)term.toUtf8()));
+    string t = (const char *)term.toUtf8();
+    string::size_type pos = t.find_last_not_of(punct);
+    if (pos == string::npos)
+	return;
+    t = t.substr(0, pos+1);
+    pos = t.find_first_not_of(punct);
+    if (pos != string::npos)
+	t = t.substr(pos);
+    if (t.empty())
+	return;
+    term = QString::fromUtf8(t.c_str());
+
+    QString text = queryText->currentText();
+    text += QString::fromLatin1(" ") + term;
+    queryText->setEditText(text);
+}
+
 void SSearch::setAnyTermMode()
 {
-    searchTypCMB->setCurrentItem(SST_ANY);
+    searchTypCMB->setCurrentIndex(SST_ANY);
 }
 
 // Complete last word in input by querying db for all possible terms.
@@ -244,13 +259,13 @@ void SSearch::completion()
 {
     if (!rcldb)
 	return;
-    if (searchTypCMB->currentItem() == SST_FNM) {
+    if (searchTypCMB->currentIndex() == SST_FNM) {
 	// Filename: no completion
 	QApplication::beep();
 	return;
     }
     // Extract last word in text
-    string txt = (const char *)queryText->currentText().utf8();
+    string txt = (const char *)queryText->currentText().toUtf8();
     string::size_type cs = txt.find_last_of(" ");
     if (cs == string::npos)
 	cs = 0;
@@ -266,7 +281,7 @@ void SSearch::completion()
     // Query database
     const int max = 100;
     Rcl::TermMatchResult tmres;
-    string stemLang = (const char *)prefs.queryStemLang.ascii();
+    string stemLang = (const char *)prefs.queryStemLang.toAscii();
     if (stemLang == "ALL") {
 	rclconfig->getConfParam("indexstemminglanguages", stemLang);
     }
@@ -292,15 +307,15 @@ void SSearch::completion()
 	     it != tmres.entries.end(); it++) {
 	    lst.push_back(QString::fromUtf8(it->term.c_str()));
 	}
-	res = QInputDialog::getItem(tr("Completions"),
-				    tr("Select an item:"), lst, 0, 
-				    FALSE, &ok, this);
+	res = QInputDialog::getItem (this, tr("Completions"), 
+				     tr("Select an item:"),
+				     lst, 0, false, &ok);
     }
 
     // Insert result
     if (ok) {
 	txt.erase(cs);
-	txt.append(res.utf8());
+	txt.append((const char *)res.toUtf8());
 	queryText->setEditText(QString::fromUtf8(txt.c_str()));
     } else {
 	return;
@@ -309,91 +324,7 @@ void SSearch::completion()
 
 #undef SHOWEVENTS
 #if defined(SHOWEVENTS)
-#if QT_VERSION < 0x040000
-static const char *eventTypeToStr(int tp)
-{
-    switch (tp) {
-    case 0: return "None";
-    case 1: return "Timer";
-    case 2: return "MouseButtonPress";
-    case 3: return "MouseButtonRelease";
-    case 4: return "MouseButtonDblClick";
-    case 5: return "MouseMove";
-    case 6: return "KeyPress";
-    case 7: return "KeyRelease";
-    case 8: return "FocusIn";
-    case 9: return "FocusOut";
-    case 10: return "Enter";
-    case 11: return "Leave";
-    case 12: return "Paint";
-    case 13: return "Move";
-    case 14: return "Resize";
-    case 15: return "Create";
-    case 16: return "Destroy";
-    case 17: return "Show";
-    case 18: return "Hide";
-    case 19: return "Close";
-    case 20: return "Quit";
-    case 21: return "Reparent";
-    case 22: return "ShowMinimized";
-    case 23: return "ShowNormal";
-    case 24: return "WindowActivate";
-    case 25: return "WindowDeactivate";
-    case 26: return "ShowToParent";
-    case 27: return "HideToParent";
-    case 28: return "ShowMaximized";
-    case 29: return "ShowFullScreen";
-    case 30: return "Accel";
-    case 31: return "Wheel";
-    case 32: return "AccelAvailable";
-    case 33: return "CaptionChange";
-    case 34: return "IconChange";
-    case 35: return "ParentFontChange";
-    case 36: return "ApplicationFontChange";
-    case 37: return "ParentPaletteChange";
-    case 38: return "ApplicationPaletteChange";
-    case 39: return "PaletteChange";
-    case 40: return "Clipboard";
-    case 42: return "Speech";
-    case 50: return "SockAct";
-    case 51: return "AccelOverride";
-    case 52: return "DeferredDelete";
-    case 60: return "DragEnter";
-    case 61: return "DragMove";
-    case 62: return "DragLeave";
-    case 63: return "Drop";
-    case 64: return "DragResponse";
-    case 70: return "ChildInserted";
-    case 71: return "ChildRemoved";
-    case 72: return "LayoutHint";
-    case 73: return "ShowWindowRequest";
-    case 74: return "WindowBlocked";
-    case 75: return "WindowUnblocked";
-    case 80: return "ActivateControl";
-    case 81: return "DeactivateControl";
-    case 82: return "ContextMenu";
-    case 83: return "IMStart";
-    case 84: return "IMCompose";
-    case 85: return "IMEnd";
-    case 86: return "Accessibility";
-    case 87: return "TabletMove";
-    case 88: return "LocaleChange";
-    case 89: return "LanguageChange";
-    case 90: return "LayoutDirectionChange";
-    case 91: return "Style";
-    case 92: return "TabletPress";
-    case 93: return "TabletRelease";
-    case 94: return "OkRequest";
-    case 95: return "HelpRequest";
-    case 96: return "WindowStateChange";
-    case 97: return "IconDrag";
-    case 1000: return "User";
-    case 65535: return "MaxUser";
-    default: return "Unknown";
-    }
-}
-#else
-static const char *eventTypeToStr(int tp)
+const char *eventTypeToStr(int tp)
 {
     switch (tp) {
     case  0: return "None";
@@ -531,7 +462,6 @@ static const char *eventTypeToStr(int tp)
     }
 }
 #endif
-#endif
 
 bool SSearch::eventFilter(QObject *, QEvent *event)
 {
