@@ -31,29 +31,19 @@ static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.26 2008-10-03 08:09:36 dockes E
 #include <qvariant.h>
 #include <qpushbutton.h>
 #include <qtabwidget.h>
+#include <qlistwidget.h>
 #include <qwidget.h>
 #include <qlabel.h>
 #include <qspinbox.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
-#if QT_VERSION < 0x040000
-#include <qlistbox.h>
-#include <qlistview.h>
 #include <qfiledialog.h>
-#else
-#include <q3listbox.h>
-#include <q3listview.h>
-#include <q3filedialog.h>
-#define QListView Q3ListView
-#define QCheckListItem Q3CheckListItem
-#define QFileDialog  Q3FileDialog
-#define QListViewItemIterator Q3ListViewItemIterator
-#endif
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 #include <qtextedit.h>
+#include <qlist.h>
 
 #include "recoll.h"
 #include "guiutils.h"
@@ -62,6 +52,7 @@ static char rcsid[] = "@(#$Id: uiprefs_w.cpp,v 1.26 2008-10-03 08:09:36 dockes E
 #include "pathut.h"
 #include "uiprefs_w.h"
 #include "viewaction_w.h"
+#include "debuglog.h"
 
 void UIPrefsDialog::init()
 {
@@ -70,8 +61,6 @@ void UIPrefsDialog::init()
     connect(viewActionPB, SIGNAL(clicked()), this, SLOT(showViewAction()));
     connect(reslistFontPB, SIGNAL(clicked()), this, SLOT(showFontDialog()));
     connect(resetFontPB, SIGNAL(clicked()), this, SLOT(resetReslistFont()));
-    connect(extraDbLE,SIGNAL(textChanged(const QString&)), this, 
-	    SLOT(extraDbTextChanged(const QString&)));
 
     connect(addExtraDbPB, SIGNAL(clicked()), 
 	    this, SLOT(addExtraDbPB_clicked()));
@@ -84,7 +73,6 @@ void UIPrefsDialog::init()
     connect(unacAllExtraDbPB, SIGNAL(clicked()), 
 	    this, SLOT(unacAllExtraDbPB_clicked()));
 
-    connect(browseDbPB, SIGNAL(clicked()), this, SLOT(browseDbPB_clicked()));
     connect(buttonOk, SIGNAL(clicked()), this, SLOT(accept()));
     connect(buttonCancel, SIGNAL(clicked()), this, SLOT(reject()));
     connect(buildAbsCB, SIGNAL(toggled(bool)), 
@@ -108,7 +96,6 @@ void UIPrefsDialog::setFromPrefs()
     syntctxSB->setValue(prefs.syntAbsCtx);
 
     initStartAdvCB->setChecked(prefs.startWithAdvSearchOpen);
-    initStartSortCB->setChecked(prefs.startWithSortToolOpen);
 
     // External editor. Can use desktop prefs or internal
     useDesktopOpenCB->setChecked(prefs.useDesktopOpen);
@@ -130,12 +117,12 @@ void UIPrefsDialog::setFromPrefs()
 	reslistFontPB->setText(reslistFontFamily + "-" +
 			       s.setNum(reslistFontSize));
     }
-    rlfTE->setText(prefs.reslistformat);
+    rlfTE->setPlainText(prefs.reslistformat);
 
     // Stemming language combobox
     stemLangCMB->clear();
-    stemLangCMB->insertItem(g_stringNoStem);
-    stemLangCMB->insertItem(g_stringAllStem);
+    stemLangCMB->addItem(g_stringNoStem);
+    stemLangCMB->addItem(g_stringAllStem);
     list<string> langs;
     if (!getStemLangs(langs)) {
 	QMessageBox::warning(0, "Recoll", 
@@ -145,12 +132,13 @@ void UIPrefsDialog::setFromPrefs()
     for (list<string>::const_iterator it = langs.begin(); 
 	 it != langs.end(); it++) {
 	stemLangCMB->
-	    insertItem(QString::fromAscii(it->c_str(), it->length()));
-	if (cur == 0 && !strcmp(prefs.queryStemLang.ascii(), it->c_str())) {
+	    addItem(QString::fromAscii(it->c_str(), it->length()));
+	if (cur == 0 && !strcmp((const char*)prefs.queryStemLang.toAscii(), 
+				it->c_str())) {
 	    cur = stemLangCMB->count();
 	}
     }
-    stemLangCMB->setCurrentItem(cur);
+    stemLangCMB->setCurrentIndex(cur);
 
     autoPhraseCB->setChecked(prefs.ssearchAutoPhrase);
 
@@ -165,19 +153,23 @@ void UIPrefsDialog::setFromPrefs()
     idxLV->clear();
     for (list<string>::iterator it = prefs.allExtraDbs.begin(); 
 	 it != prefs.allExtraDbs.end(); it++) {
-	QCheckListItem *item = 
-	    new QCheckListItem(idxLV, QString::fromLocal8Bit(it->c_str()), 
-			       QCheckListItem::CheckBox);
-	if (item) item->setOn(false);
+	QListWidgetItem *item = 
+	    new QListWidgetItem(QString::fromLocal8Bit(it->c_str()), 
+				idxLV);
+	if (item) 
+	    item->setCheckState(Qt::Unchecked);
     }
     for (list<string>::iterator it = prefs.activeExtraDbs.begin(); 
 	 it != prefs.activeExtraDbs.end(); it++) {
-	QCheckListItem *item;
-	if ((item = (QCheckListItem *)
-	     idxLV->findItem (QString::fromLocal8Bit(it->c_str()), 0))) {
-	    item->setOn(true);
+	QList<QListWidgetItem *>items =
+	     idxLV->findItems (QString::fromLocal8Bit(it->c_str()), 
+			       Qt::MatchFixedString|Qt::MatchCaseSensitive);
+	for (QList<QListWidgetItem *>::iterator it = items.begin(); 
+	     it != items.end(); it++) {
+	    (*it)->setCheckState(Qt::Checked);
 	}
     }
+    idxLV->sortItems();
 }
 
 void UIPrefsDialog::accept()
@@ -191,23 +183,16 @@ void UIPrefsDialog::accept()
     prefs.qtermcolor = qtermColorLE->text();
     prefs.reslistfontfamily = reslistFontFamily;
     prefs.reslistfontsize = reslistFontSize;
-    prefs.reslistformat =  rlfTE->text();
-    // Don't let us set the old default format from here, this would
-    // get reset to the new default. Ugly hack
-    if (prefs.reslistformat == 
-	QString::fromAscii(prefs.getV18DfltResListFormat())) {
-	prefs.reslistformat += " ";
-	rlfTE->setText(prefs.reslistformat);
+    prefs.reslistformat =  rlfTE->toPlainText();
+    if (prefs.reslistformat.trimmed().isEmpty()) {
+	prefs.reslistformat = prefs.dfltResListFormat;
+	rlfTE->setPlainText(prefs.reslistformat);
     }
-    if (prefs.reslistformat.stripWhiteSpace().isEmpty()) {
-	prefs.reslistformat = prefs.getDfltResListFormat();
-	rlfTE->setText(prefs.reslistformat);
-    }
-    prefs.creslistformat = (const char*)prefs.reslistformat.utf8();
+    prefs.creslistformat = (const char*)prefs.reslistformat.toUtf8();
 
-    if (stemLangCMB->currentItem() == 0) {
+    if (stemLangCMB->currentIndex() == 0) {
 	prefs.queryStemLang = "";
-    } else if (stemLangCMB->currentItem() == 1) {
+    } else if (stemLangCMB->currentIndex() == 1) {
 	prefs.queryStemLang = "ALL";
     } else {
 	prefs.queryStemLang = stemLangCMB->currentText();
@@ -218,7 +203,6 @@ void UIPrefsDialog::accept()
 	replAbsCB->isChecked();
 
     prefs.startWithAdvSearchOpen = initStartAdvCB->isChecked();
-    prefs.startWithSortToolOpen = initStartSortCB->isChecked();
     prefs.useDesktopOpen = useDesktopOpenCB->isChecked();
     prefs.keepSort = keepSortCB->isChecked();
     prefs.previewHtml = previewHtmlCB->isChecked();
@@ -230,17 +214,17 @@ void UIPrefsDialog::accept()
     prefs.autoSuffsEnable = autoSuffsCB->isChecked();
     prefs.autoSuffs = autoSuffsLE->text();
 
-    QListViewItemIterator it(idxLV);
     prefs.allExtraDbs.clear();
     prefs.activeExtraDbs.clear();
-    while (it.current()) {
-	QCheckListItem *item = (QCheckListItem *)it.current();
-	prefs.allExtraDbs.push_back((const char *)item->text().local8Bit());
-	if (item->isOn()) {
-	    prefs.activeExtraDbs.push_back((const char *)
-					   item->text().local8Bit());
+    for (int i = 0; i < idxLV->count(); i++) {
+	QListWidgetItem *item = idxLV->item(i);
+	if (item) {
+	    prefs.allExtraDbs.push_back((const char *)item->text().toLocal8Bit());
+	    if (item->checkState() == Qt::Checked) {
+		prefs.activeExtraDbs.push_back((const char *)
+					       item->text().toLocal8Bit());
+	    }
 	}
-	++it;
     }
 
     rwSettings(true);
@@ -265,13 +249,13 @@ void UIPrefsDialog::setStemLang(const QString& lang)
 	cur = 1;
     } else {
 	for (int i = 1; i < stemLangCMB->count(); i++) {
-	    if (lang == stemLangCMB->text(i)) {
+	    if (lang == stemLangCMB->itemText(i)) {
 		cur = i;
 		break;
 	    }
 	}
     }
-    stemLangCMB->setCurrentItem(cur);
+    stemLangCMB->setCurrentIndex(cur);
 }
 
 void UIPrefsDialog::showFontDialog()
@@ -327,46 +311,62 @@ void UIPrefsDialog::showViewAction(const QString& mt)
 
 ////////////////////////////////////////////
 // External / extra search indexes setup
-// TBD: a way to remove entry from 'all' list (del button?)
 
 void UIPrefsDialog::togExtraDbPB_clicked()
 {
-    QListViewItemIterator it(idxLV);
-    while (it.current()) {
-	QCheckListItem *item = (QCheckListItem *)it.current();
+    for (int i = 0; i < idxLV->count(); i++) {
+	QListWidgetItem *item = idxLV->item(i);
 	if (item->isSelected()) {
-	    item->setOn(!item->isOn());
+	    if (item->checkState() == Qt::Checked) {
+		item->setCheckState(Qt::Unchecked);
+	    } else {
+		item->setCheckState(Qt::Checked);
+	    }
 	}
-	++it;
     }
 }
 void UIPrefsDialog::actAllExtraDbPB_clicked()
 {
-    QListViewItemIterator it(idxLV);
-    while (it.current()) {
-	QCheckListItem *item = (QCheckListItem *)it.current();
-	item->setOn(true);
-	++it;
+    for (int i = 0; i < idxLV->count(); i++) {
+	QListWidgetItem *item = idxLV->item(i);
+	    item->setCheckState(Qt::Checked);
     }
 }
 void UIPrefsDialog::unacAllExtraDbPB_clicked()
 {
-    QListViewItemIterator it(idxLV);
-    while (it.current()) {
-	QCheckListItem *item = (QCheckListItem *)it.current();
-	item->setOn(false);
-	++it;
+    for (int i = 0; i < idxLV->count(); i++) {
+	QListWidgetItem *item = idxLV->item(i);
+	    item->setCheckState(Qt::Unchecked);
+    }
+}
+
+void UIPrefsDialog::delExtraDbPB_clicked()
+{
+    QList<QListWidgetItem *> items = idxLV->selectedItems();
+    for (QList<QListWidgetItem *>::iterator it = items.begin(); 
+	 it != items.end(); it++) {
+	delete *it;
     }
 }
 
 /** 
- * Add the current content of the extra db line editor to the list of all
- * extra dbs. We do a textual comparison to check for duplicates, except for
+ * Browse to add another index.
+ * We do a textual comparison to check for duplicates, except for
  * the main db for which we check inode numbers. 
  */
 void UIPrefsDialog::addExtraDbPB_clicked()
 {
-    string dbdir = (const char *)extraDbLE->text().local8Bit();
+    static QString lastdir;
+
+    QString input = QFileDialog::getExistingDirectory(this,
+      tr("Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)"),
+						      lastdir);
+    if (input.isEmpty())
+	return;
+    lastdir = input;
+
+    string dbdir = (const char *)input.toLocal8Bit();
+    LOGDEB(("ExtraDbDial: got: [%s]\n", dbdir.c_str()));
     path_catslash(dbdir);
     if (!Rcl::Db::testDbDir(dbdir)) {
 	QMessageBox::warning(0, "Recoll", 
@@ -375,64 +375,40 @@ void UIPrefsDialog::addExtraDbPB_clicked()
     }
     struct stat st1, st2;
     stat(dbdir.c_str(), &st1);
-    string rcldbdir = RclConfig::getMainConfig()->getDbDir();
+    string rcldbdir = rclconfig->getDbDir();
     stat(rcldbdir.c_str(), &st2);
     path_catslash(rcldbdir);
-    fprintf(stderr, "rcldbdir: [%s]\n", rcldbdir.c_str());
+
     if (st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino) {
 	QMessageBox::warning(0, "Recoll", 
 			     tr("This is the main/local index!"));
 	return;
     }
-    if (idxLV->findItem(extraDbLE->text(), 
-#if QT_VERSION < 0x040000
-			    Qt::CaseSensitive|Qt::ExactMatch
-#else
-			    Q3ListView::CaseSensitive|Q3ListView::ExactMatch
-#endif
-				    )) {
-	QMessageBox::warning(0, "Recoll", 
-		 tr("The selected directory is already in the index list"));
-	return;
-    }
-    new QCheckListItem(idxLV, extraDbLE->text(), QCheckListItem::CheckBox);
-    idxLV->sort();
-}
 
-void UIPrefsDialog::delExtraDbPB_clicked()
-{
-    list<QCheckListItem*> dlt;
+    // For some reason, finditem (which we used to use to detect duplicates 
+    // here) does not work anymore here: qt 4.6.3
+    QList<QListWidgetItem *>items =
+	idxLV->findItems (input, Qt::MatchFixedString|Qt::MatchCaseSensitive);
+    if (!items.empty()) {
+	    QMessageBox::warning(0, "Recoll", 
+		 tr("The selected directory is already in the index list"));
+	    return;
+    }
+#if 0
+    string nv = (const char *)input.toLocal8Bit();
     QListViewItemIterator it(idxLV);
     while (it.current()) {
 	QCheckListItem *item = (QCheckListItem *)it.current();
-	if (item->isSelected()) {
-	    dlt.push_back(item);
+	string ov = (const char *)item->text().toLocal8Bit();
+	if (!ov.compare(nv)) {
+	    QMessageBox::warning(0, "Recoll", 
+		 tr("The selected directory is already in the index list"));
+	    return;
 	}
 	++it;
     }
-    for (list<QCheckListItem*>::iterator it = dlt.begin(); 
-	 it != dlt.end(); it++) 
-	delete *it;
-}
-
-void UIPrefsDialog::extraDbTextChanged(const QString &text)
-{
-    if (text.isEmpty()) {
-	addExtraDbPB->setEnabled(false);
-    } else {
-	addExtraDbPB->setEnabled(true);
-    }
-}
-
-void UIPrefsDialog::browseDbPB_clicked()
-{
-    QFileDialog fdia;
-    bool savedh = fdia.showHiddenFiles();
-    fdia.setShowHiddenFiles(true);
-    QString s = QFileDialog::getExistingDirectory("", this, 0, 
-       tr("Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)"));
-
-    fdia.setShowHiddenFiles(savedh);
-    if (!s.isEmpty()) 
-	extraDbLE->setText(s);
+#endif
+    QListWidgetItem *item = new QListWidgetItem(input, idxLV);
+    item->setCheckState(Qt::Unchecked);
+    idxLV->sortItems();
 }
