@@ -28,9 +28,12 @@ static char rcsid[] = "@(#$Id: docseqdb.cpp,v 1.9 2008-11-13 10:57:46 dockes Exp
 DocSequenceDb::DocSequenceDb(RefCntr<Rcl::Query> q, const string &t, 
 			     RefCntr<Rcl::SearchData> sdata) 
     : DocSequence(t), m_q(q), m_sdata(sdata), m_fsdata(sdata),
-      m_rescnt(-1), m_filt(false),
+      m_rescnt(-1), 
       m_queryBuildAbstract(true),
-      m_queryReplaceAbstract(false)
+      m_queryReplaceAbstract(false),
+      m_isFiltered(false),
+      m_isSorted(false),
+      m_needSetQuery(false)
 {
 }
 
@@ -57,12 +60,14 @@ string DocSequenceDb::getDescription()
 
 bool DocSequenceDb::getDoc(int num, Rcl::Doc &doc, string *sh)
 {
+    setQuery();
     if (sh) sh->erase();
     return m_q->getDoc(num, doc);
 }
 
 int DocSequenceDb::getResCnt()
 {
+    setQuery();
     if (m_rescnt < 0) {
 	m_rescnt= m_q->getResCnt();
     }
@@ -71,6 +76,7 @@ int DocSequenceDb::getResCnt()
 
 string DocSequenceDb::getAbstract(Rcl::Doc &doc)
 {
+    setQuery();
     if (!m_q->whatDb())
 	return doc.meta[Rcl::Doc::keyabs];
     string abstract;
@@ -86,6 +92,7 @@ string DocSequenceDb::getAbstract(Rcl::Doc &doc)
 
 bool DocSequenceDb::getEnclosing(Rcl::Doc& doc, Rcl::Doc& pdoc) 
 {
+    setQuery();
     string udi;
     if (!FileInterner::getEnclosing(doc.url, doc.ipath, pdoc.url, pdoc.ipath,
                                     udi))
@@ -95,42 +102,67 @@ bool DocSequenceDb::getEnclosing(Rcl::Doc& doc, Rcl::Doc& pdoc)
 
 list<string> DocSequenceDb::expand(Rcl::Doc &doc)
 {
+    setQuery();
     return m_q->expand(doc);
 }
 
-bool DocSequenceDb::setFiltSpec(DocSeqFiltSpec &fs) 
-{
-    if (!fs.isNotNull()) {
-	m_fsdata = m_sdata;
-	m_filt = false;
-	return m_q->setQuery(m_sdata);
-    }
-
-    // We build a search spec by adding a filtering layer to the base one.
-    m_fsdata = RefCntr<Rcl::SearchData>(new Rcl::SearchData(Rcl::SCLT_AND));
-    Rcl::SearchDataClauseSub *cl = 
-	new Rcl::SearchDataClauseSub(Rcl::SCLT_SUB, m_sdata);
-    m_fsdata->addClause(cl);
-    
-    for (unsigned int i = 0; i < fs.crits.size(); i++) {
-	switch (fs.crits[i]) {
-	case DocSeqFiltSpec::DSFS_MIMETYPE:
-	    m_fsdata->addFiletype(fs.values[i]);
-	}
-    }
-    m_filt = true;
-    return m_q->setQuery(m_fsdata);
-}
-
-// Need a way to access the translations for filtered ...
 string DocSequenceDb::title()
 {
-    LOGDEB(("DOcSequenceDb::title()\n"));
-    return m_filt ? DocSequence::title() + " (filtered)" : DocSequence::title();
+    string qual;
+    if (m_isFiltered && !m_isSorted)
+	qual = string(" (") + o_filt_trans + string(")");
+    else if (!m_isFiltered && m_isSorted)
+	qual = string(" (") + o_sort_trans + string(")");
+    else if (m_isFiltered && m_isSorted)
+	qual = string(" (") + o_sort_trans + string(",") + o_filt_trans + string(")");
+    return DocSequence::title() + qual;
 }
 
-// TBDone
-bool DocSequenceDb::setSortSpec(DocSeqSortSpec &sortspec) 
+bool DocSequenceDb::setFiltSpec(const DocSeqFiltSpec &fs) 
 {
+    LOGDEB(("DocSequenceDb::setFiltSpec\n"));
+    if (fs.isNotNull()) {
+	// We build a search spec by adding a filtering layer to the base one.
+	m_fsdata = RefCntr<Rcl::SearchData>(new Rcl::SearchData(Rcl::SCLT_AND));
+	Rcl::SearchDataClauseSub *cl = 
+	    new Rcl::SearchDataClauseSub(Rcl::SCLT_SUB, m_sdata);
+	m_fsdata->addClause(cl);
+    
+	for (unsigned int i = 0; i < fs.crits.size(); i++) {
+	    switch (fs.crits[i]) {
+	    case DocSeqFiltSpec::DSFS_MIMETYPE:
+		m_fsdata->addFiletype(fs.values[i]);
+	    }
+	}
+	m_isFiltered = true;
+    } else {
+	m_fsdata = m_sdata;
+	m_isFiltered = false;
+    }
+    m_needSetQuery = true;
     return true;
 }
+
+bool DocSequenceDb::setSortSpec(const DocSeqSortSpec &spec) 
+{
+    LOGDEB(("DocSequenceDb::setSortSpec: fld [%s] %s\n", 
+	    spec.field.c_str(), spec.desc ? "desc" : "asc"));
+    if (spec.isNotNull()) {
+	m_q->setSortBy(spec.field, !spec.desc);
+	m_isSorted = true;
+    } else {
+	m_q->setSortBy(string(), true);
+	m_isSorted = false;
+    }
+    m_needSetQuery = true;
+    return true;
+}
+
+bool DocSequenceDb::setQuery()
+{
+    if (!m_needSetQuery)
+	return true;
+    m_rescnt = -1;
+    m_needSetQuery = !m_q->setQuery(m_fsdata);
+    return !m_needSetQuery;
+}
