@@ -248,7 +248,7 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	if (sd)
 	    sd->addClause(clp);
     } else {
-	sd = wasaStringToRcl(qs, reason);
+	sd = wasaStringToRcl(rclconfig, qs, reason);
     }
 
     if (!sd) {
@@ -325,11 +325,6 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 
 static RclConfig *rclconfig;
 
-RclConfig *RclConfig::getMainConfig() 
-{
-    return rclconfig;
-}
-
 int main(int argc, char **argv)
 {
     exit(recollq(&rclconfig, argc, argv));
