@@ -8,31 +8,26 @@ using std::vector;
 #include "refcntr.h"
 #include "docseq.h"
 
+class RclConfig;
 class PlainToRich;
+class HiliteData;
 
 /**
  * Manage a paged HTML result list. 
  */
 class ResListPager {
 public:
-    ResListPager(int pagesize=10) :
-        m_pagesize(pagesize),
-        m_newpagesize(pagesize),
-        m_winfirst(-1),
-        m_hasNext(false),
-        m_hiliter(0)
-    {
-    }
+    ResListPager(int pagesize=10);
     virtual ~ResListPager() {}
 
     void setHighLighter(PlainToRich *ptr) 
     {
         m_hiliter = ptr;
     }
-    void setDocSource(RefCntr<DocSequence> src)
+    void setDocSource(RefCntr<DocSequence> src, int winfirst = -1)
     {
         m_pagesize = m_newpagesize;
-	m_winfirst = -1;
+	m_winfirst = winfirst;
 	m_hasNext = false;
 	m_docSource = src;
 	m_respage.clear();
@@ -47,6 +42,14 @@ public:
 	    return -1;
 	return m_winfirst / m_pagesize;
     }
+    int pageFirstDocNum() {
+	return m_winfirst;
+    }
+    int pageLastDocNum() {
+	if (m_winfirst < 0 || m_respage.size() == 0)
+	    return -1;
+	return m_winfirst + m_respage.size() - 1;
+    }
     virtual int pageSize() const {return m_pagesize;}
     void pageNext();
     bool hasNext() {return m_hasNext;}
@@ -63,7 +66,9 @@ public:
 	resultPageNext();
     }
     void resultPageNext();
-    void displayPage();
+    void displayPage(RclConfig *);
+    void displayDoc(RclConfig *, int idx, Rcl::Doc& doc, 
+		    const HiliteData& hdata, const string& sh = "");
     bool pageEmpty() {return m_respage.size() == 0;}
 
     string queryDescription() {return m_docSource.isNull() ? "" :
@@ -87,7 +92,7 @@ public:
     virtual string nextUrl();
     virtual string prevUrl();
     virtual string pageTop() {return string();}
-    virtual string iconPath(const string& mtype);
+    virtual string iconPath(RclConfig *, const string& mtype);
     virtual void suggest(const vector<string>, vector<string>&sugg) {
         sugg.clear();
     }
