@@ -74,6 +74,8 @@ static const unsigned int baseTextPosition = 100000;
 namespace Rcl {
 #endif
 
+const string pathelt_prefix = "XP";
+
 string version_string(){
     return string("Recoll ") + string(rclversionstr) + string(" + Xapian ") +
         string(Xapian::version_string());
@@ -103,6 +105,12 @@ static inline string make_parentterm(const string& udi)
     return pterm;
 }
 
+static inline void leftzeropad(string& s, unsigned len)
+{
+    if (s.length() && s.length() < len)
+	s = s.insert(0, len - s.length(), '0');
+}
+
 /* See comment in class declaration: return all subdocuments of a
  * document given by its unique id. 
 */
@@ -132,9 +140,9 @@ static const string keycap("caption");
 
 // Turn data record from db into document fields
 bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data, 
-				Doc &doc, int percent)
+				Doc &doc)
 {
-    LOGDEB0(("Db::dbDataToRclDoc: data: %s\n", data.c_str()));
+    LOGDEB2(("Db::dbDataToRclDoc: data:\n%s\n", data.c_str()));
     ConfSimple parms(data);
     if (!parms.ok())
 	return false;
@@ -153,10 +161,6 @@ bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data,
 	doc.meta[Doc::keyabs] = doc.meta[Doc::keyabs].substr(rclSyntAbs.length());
 	doc.syntabs = true;
     }
-    char buf[20];
-    sprintf(buf,"%.2f", float(percent) / 100.0);
-    doc.pc = percent;
-    doc.meta[Doc::keyrr] = buf;
     parms.get(Doc::keyipt, doc.ipath);
     parms.get(Doc::keyfs, doc.fbytes);
     parms.get(Doc::keyds, doc.dbytes);
@@ -170,6 +174,7 @@ bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data,
 	if (doc.meta.find(*it) == doc.meta.end()) 
 	    parms.get(*it, doc.meta[*it]);
     }
+    doc.meta[Doc::keymt] = doc.dmtime.empty() ? doc.fmtime : doc.dmtime;
     return true;
 }
 
@@ -216,7 +221,7 @@ static void listList(const string& what, const list<string>&l)
 string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 {
     Chrono chron;
-    LOGDEB(("makeAbstract:%d: maxlen %d wWidth %d\n", chron.ms(),
+    LOGDEB0(("makeAbstract:%d: maxlen %d wWidth %d\n", chron.ms(),
 	     m_rcldb->m_synthAbsLen, m_rcldb->m_synthAbsWordCtxLen));
 
     list<string> terms;
@@ -244,7 +249,7 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 	for (list<string>::const_iterator qit = qterms.begin(); 
 	     qit != qterms.end(); qit++) {
 	    query->m_nq->termfreqs[*qit] = xrdb.get_termfreq(*qit) / doccnt;
-	    LOGDEB(("makeAbstract: [%s] db freq %.1e\n", qit->c_str(), 
+	    LOGABS(("makeAbstract: [%s] db freq %.1e\n", qit->c_str(), 
 		    query->m_nq->termfreqs[*qit]));
 	}
 	LOGABS(("makeAbstract:%d: got termfreqs\n", chron.ms()));
@@ -424,7 +429,7 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 	    if ('A' <= (*term).at(0) && (*term).at(0) <= 'Z')
 		continue;
 	    if (cutoff-- < 0) {
-		LOGDEB(("makeAbstract: max term count cutoff\n"));
+		LOGDEB0(("makeAbstract: max term count cutoff\n"));
 		break;
 	    }
 
@@ -432,7 +437,7 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
 	    for (pos = xrdb.positionlist_begin(docid, *term); 
 		 pos != xrdb.positionlist_end(docid, *term); pos++) {
 		if (cutoff-- < 0) {
-		    LOGDEB(("makeAbstract: max term count cutoff\n"));
+		    LOGDEB0(("makeAbstract: max term count cutoff\n"));
 		    break;
 		}
 		map<unsigned int, string>::iterator vit;
@@ -495,7 +500,7 @@ string Db::Native::makeAbstract(Xapian::docid docid, Query *query)
     if (!abstract.compare("... "))
 	abstract.clear();
 
-    LOGDEB(("makeAbtract: done in %d mS\n", chron.millis()));
+    LOGDEB0(("makeAbtract: done in %d mS\n", chron.millis()));
     return abstract;
 }
 
@@ -810,9 +815,8 @@ private:
 // Get one term from the doc, remove accents and lowercase, then add posting
 bool TextSplitDb::takeword(const std::string &_term, int pos, int, int)
 {
-#if 0
-    LOGDEB(("TextSplitDb::takeword: [%s]\n", _term.c_str()));
-#endif
+    LOGDEB2(("TextSplitDb::takeword: [%s]\n", _term.c_str()));
+
     string term;
     if (!unacmaybefold(_term, term, "UTF-8", true)) {
 	LOGINFO(("Db::splitter::takeword: unac failed for [%s]\n", 
@@ -859,12 +863,6 @@ void Db::setAbstractParams(int idxtrunc, int syntlen, int syntctxlen)
 	m_synthAbsWordCtxLen = syntctxlen;
 }
 
-static inline void leftzeropad(string& s, unsigned len)
-{
-    if (s.length() && s.length() < len)
-	s = s.insert(0, len-s.length(), '0');
-}
-
 static const int MB = 1024 * 1024;
 static const string nc("\n\r\x0c");
 
@@ -921,7 +919,28 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 	    splitter.basepos += splitter.curpos + 100;
 	}
     }
-	    
+
+    // Split and index the path from the url for path-based filtering
+    {
+	string path = url_gpath(doc.url);
+	vector<string> vpath;
+	stringToTokens(path, vpath, "/");
+	splitter.curpos = 0;
+	newdocument.add_posting(pathelt_prefix, 
+				splitter.basepos + splitter.curpos++);
+	for (vector<string>::iterator it = vpath.begin(); 
+	     it != vpath.end(); it++){
+	    if (it->length() > 230) {
+		// Just truncate it. May still be useful because of wildcards
+		*it = it->substr(0, 230);
+	    }
+	    newdocument.add_posting(pathelt_prefix + *it, 
+				    splitter.basepos + splitter.curpos++);
+	}
+    }
+    splitter.basepos += splitter.curpos + 100;
+
+
     // Index textual metadata.  These are all indexed as text with
     // positions, as we may want to do phrase searches with them (this
     // makes no sense for keywords by the way).
@@ -938,8 +957,8 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi,
 		continue;
 	    }
 	    LOGDEB0(("Db::add: field [%s] pfx [%s]: [%s]\n", 
-		    meta_it->first.c_str(), pfx.c_str(), 
-		    meta_it->second.c_str()));
+		     meta_it->first.c_str(), pfx.c_str(), 
+		     meta_it->second.c_str()));
 	    splitter.setprefix(pfx); // Subject
 	    if (!splitter.text_to_words(meta_it->second))
                 LOGDEB(("Db::addOrUpdate: split failed for %s\n", 
@@ -1363,13 +1382,16 @@ bool Db::filenameWildExp(const string& fnexp, list<string>& names)
     string pattern = fnexp;
     names.clear();
 
-    // If pattern is not quoted, and has no wildcards, we add * at
+    // If pattern is not capitalized, not quoted (quoted pattern can't
+    // get here currently anyway), and has no wildcards, we add * at
     // each end: match any substring
     if (pattern[0] == '"' && pattern[pattern.size()-1] == '"') {
 	pattern = pattern.substr(1, pattern.size() -2);
-    } else if (pattern.find_first_of("*?[") == string::npos) {
+    } else if (pattern.find_first_of("*?[") == string::npos && 
+	       !unaciscapital(pattern)) {
 	pattern = "*" + pattern + "*";
     } // else let it be
+
     LOGDEB(("Rcl::Db::filenameWildExp: pattern: [%s]\n", pattern.c_str()));
 
     TermMatchResult result;
@@ -1698,6 +1720,7 @@ bool Db::getDoc(const string &udi, Doc &doc)
 
     // Initialize what we can in any case. If this is history, caller
     // will make partial display in case of error
+    doc.meta[Rcl::Doc::keyrr] = "100%";
     doc.pc = 100;
 
     string uniterm = make_uniterm(udi);
@@ -1718,7 +1741,7 @@ bool Db::getDoc(const string &udi, Doc &doc)
             Xapian::Document xdoc = m_ndb->xrdb.get_document(*docid);
             string data = xdoc.get_data();
             doc.meta[Rcl::Doc::keyudi] = udi;
-            return m_ndb->dbDataToRclDoc(*docid, data, doc, 100);
+            return m_ndb->dbDataToRclDoc(*docid, data, doc);
 	} catch (const Xapian::DatabaseModifiedError &e) {
             m_reason = e.get_msg();
 	    m_ndb->xrdb.reopen();
