@@ -77,8 +77,7 @@ class Db::Native {
 
     string makeAbstract(Xapian::docid id, Query *query);
 
-    bool dbDataToRclDoc(Xapian::docid docid, std::string &data, Doc &doc,
-			int percent);
+    bool dbDataToRclDoc(Xapian::docid docid, std::string &data, Doc &doc);
 
     /** Compute list of subdocuments for a given udi. We look for documents 
      * indexed by a parent term matching the udi, the posting list for the 
@@ -104,7 +103,14 @@ class Db::Native {
 inline const string& docfToDatf(const string& df)
 {
     static const string keycap("caption");
-    return df.compare(Doc::keytt) ? df : keycap;
+    static const string keydmtime("dmtime");
+    if (!df.compare(Doc::keytt)) {
+	return keycap;
+    } else if (!df.compare(Doc::keymt)) {
+	return keydmtime;
+    } else {
+	return df;
+    }
 }
 
 }
