@@ -242,17 +242,96 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 	for (vector<string>::iterator it = exptps.begin(); 
 	     it != exptps.end(); it++) {
 	    string term = "T" + *it;
-	    LOGDEB(("Adding file type term: [%s]\n", term.c_str()));
+	    LOGDEB0(("Adding file type term: [%s]\n", term.c_str()));
 	    tq = tq.empty() ? Xapian::Query(term) : 
 		Xapian::Query(Xapian::Query::OP_OR, tq, Xapian::Query(term));
 	}
 	xq = xq.empty() ? tq : Xapian::Query(Xapian::Query::OP_FILTER, xq, tq);
     }
 
+    // Add the directory filtering clause
+    if (!m_topdir.empty()) {
+	vector<string> vpath;
+	stringToTokens(m_topdir, vpath, "/");
+	vector<string> pvpath;
+	pvpath.push_back(pathelt_prefix);
+	for (vector<string>::const_iterator it = vpath.begin(); 
+	     it != vpath.end(); it++){
+	    pvpath.push_back(pathelt_prefix + *it);
+	}
+	xq = Xapian::Query(Xapian::Query::OP_FILTER, xq, 
+			   Xapian::Query(Xapian::Query::OP_PHRASE, 
+					 pvpath.begin(), pvpath.end()));
+    }
+
     *((Xapian::Query *)d) = xq;
     return true;
 }
 
+
+bool SearchData::maybeAddAutoPhrase()
+{
+    LOGDEB0(("SearchData::maybeAddAutoPhrase()\n"));
+    if (!m_query.size()) {
+	LOGDEB2(("SearchData::maybeAddAutoPhrase: empty query\n"));
+	return false;
+    }
+
+    string field;
+    string words;
+    // Walk the clause list. If we find any non simple clause or different
+    // field names, bail out.
+    for (qlist_it_t it = m_query.begin(); it != m_query.end(); it++) {
+	SClType tp = (*it)->m_tp;
+	if (tp != SCLT_AND && tp != SCLT_OR) {
+	    LOGDEB2(("SearchData::maybeAddAutoPhrase: complex clause\n"));
+	    return false;
+	}
+	SearchDataClauseSimple *clp = 
+	    dynamic_cast<SearchDataClauseSimple*>(*it);
+	if (clp == 0) {
+	    LOGDEB2(("SearchData::maybeAddAutoPhrase: dyncast failed\n"));
+	    return false;
+	}
+	if (it == m_query.begin()) {
+	    field = clp->getfield();
+	} else {
+	    if (clp->getfield().compare(field)) {
+		LOGDEB2(("SearchData::maybeAddAutoPhrase: different fields\n"));
+		return false;
+	    }
+	}
+	if (!words.empty())
+	    words += " ";
+	words +=  clp->gettext();
+    }
+
+    if (words.find_first_of("\"*[]?") != string::npos && // has wildcards
+	TextSplit::countWords(words) <= 1) { // Just one word.
+	LOGDEB2(("SearchData::maybeAddAutoPhrase: wildcards or single word\n"));
+	return false;
+    }
+
+    SearchDataClauseDist *nclp = 
+	new SearchDataClauseDist(SCLT_PHRASE, words, 0, field);
+    if (m_tp == SCLT_OR) {
+	addClause(nclp);
+    } else {
+	// My type is AND. Change it to OR and insert two queries, one
+	// being the original query as a subquery, the other the
+	// phrase.
+	SearchData *sd = new SearchData(m_tp);
+	sd->m_query = m_query;
+	m_tp = SCLT_OR;
+	m_query.clear();
+	SearchDataClauseSub *oq = 
+	    new SearchDataClauseSub(SCLT_OR, RefCntr<SearchData>(sd));
+	addClause(oq);
+	addClause(nclp);
+    }
+    return true;
+}
+
 // Add clause to current list. OR lists cant have EXCL clauses.
 bool SearchData::addClause(SearchDataClause* cl)
 {
@@ -269,7 +348,7 @@ bool SearchData::addClause(SearchDataClause* cl)
 
 // Make me all new
 void SearchData::erase() {
-    LOGDEB(("SearchData::erase\n"));
+    LOGDEB0(("SearchData::erase\n"));
     m_tp = SCLT_AND;
     for (qlist_it_t it = m_query.begin(); it != m_query.end(); it++)
 	delete *it;
@@ -324,24 +403,14 @@ class TextSplitQ : public TextSplit {
 	LOGDEB1(("TextSplitQ::takeword: %s\n", interm.c_str()));
 
 	// Check if the first letter is a majuscule in which
-	// case we do not want to do stem expansion. Note that
-	// the test is convoluted and possibly problematic
-	string noacterm, noaclowterm;
-	if (!unacmaybefold(interm, noacterm, "UTF-8", false)) {
+	// case we do not want to do stem expansion. 
+	bool nostemexp = unaciscapital(interm);
+	string noaclowterm;
+	if (!unacmaybefold(interm, noaclowterm, "UTF-8", true)) {
 	    LOGINFO(("SearchData::splitter::takeword: unac failed for [%s]\n", 
                      interm.c_str()));
 	    return true;
-	} 
-	if (!unacmaybefold(noacterm, noaclowterm, "UTF-8", true)) {
-	    LOGINFO(("SearchData::splitter::takeword: unac failed for [%s]\n", 
-                     noacterm.c_str()));
-	    return true;
 	}
-	bool nostemexp = false;
-	Utf8Iter it1(noacterm);
-	Utf8Iter it2(noaclowterm);
-	if (*it1 != *it2)
-	    nostemexp = true;
 
 	if (stops.hasStops() && stops.isStop(noaclowterm)) {
 	    LOGDEB1(("TextSplitQ::takeword [%s] in stop list\n", 
@@ -528,7 +597,11 @@ void StringToXapianQ::processSimpleSpan(const string& span, bool nostemexp,
     string sterm; // dumb version of user term
     string prefix;
     expandTerm(nostemexp, span, exp, sterm, &prefix);
-    m_terms.insert(m_terms.end(), exp.begin(), exp.end());
+    // m_terms is used for highlighting, we don't want prefixes in there.
+    for (list<string>::const_iterator it = exp.begin(); 
+	 it != exp.end(); it++) {
+	m_terms.push_back(it->substr(prefix.size()));
+    }
     // Push either term or OR of stem-expanded set
     Xapian::Query xq(Xapian::Query::OP_OR, exp.begin(), exp.end());
 
@@ -571,8 +644,16 @@ void StringToXapianQ::processPhraseOrNear(TextSplitQ *splitData,
 
 	string sterm;
 	list<string>exp;
-	expandTerm(nostemexp, *it, exp, sterm);
-	groups.push_back(vector<string>(exp.begin(), exp.end()));
+	string prefix;
+	expandTerm(nostemexp, *it, exp, sterm, &prefix);
+
+	// groups is used for highlighting, we don't want prefixes in there.
+	vector<string> noprefs;
+	for (list<string>::const_iterator it = exp.begin(); 
+	     it != exp.end(); it++) {
+	    noprefs.push_back(it->substr(prefix.size()));
+	}
+	groups.push_back(noprefs);
 	orqueries.push_back(Xapian::Query(Xapian::Query::OP_OR, 
 					  exp.begin(), exp.end()));
 #ifdef XAPIAN_NEAR_EXPAND_SINGLE_BUF
@@ -749,8 +830,15 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p,
     return true;
 }
 
-// Translate a FILENAME search clause. Actually this is now mostly
-// a "filename" field search.
+// Translate a FILENAME search clause. This mostly (or always) comes
+// from a "filename" search from the gui or recollq. A query language
+// "filename:"-prefixed field will not go through here, but through
+// the generic field-processing code.
+//
+// In the case of multiple space-separated fragments, we generate an
+// AND of OR queries. Each OR query comes from the expansion of a
+// fragment. We used to generate a single OR with all expanded terms,
+// which did not make much sense.
 bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p, 
 					     const string&)
 {
@@ -764,10 +852,10 @@ bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p,
 	 it != patterns.end(); it++) {
 	list<string> more;
 	db.filenameWildExp(*it, more);
-	names.splice(names.end(), more);
+	Xapian::Query tq = Xapian::Query(Xapian::Query::OP_OR, more.begin(), 
+					 more.end());
+	*qp = qp->empty() ? tq : Xapian::Query(Xapian::Query::OP_AND, *qp, tq);
     }
-    // Build a query out of the matching file name terms.
-    *qp = Xapian::Query(Xapian::Query::OP_OR, names.begin(), names.end());
     return true;
 }
 
@@ -793,13 +881,12 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p,
 	(m_parentSearch && !m_parentSearch->haveWildCards()) || 
 	(m_parentSearch == 0 && !m_haveWildCards);
 
-    // We produce a single phrase out of the user entry (there should be
-    // no dquotes in there), then use stringToXapianQueries() to
-    // lowercase and simplify the phrase terms etc. This will result
-    // into a single (complex) Xapian::Query.
+    // We produce a single phrase out of the user entry then use
+    // stringToXapianQueries() to lowercase and simplify the phrase
+    // terms etc. This will result into a single (complex)
+    // Xapian::Query.
     if (m_text.find_first_of("\"") != string::npos) {
-	LOGDEB(("Double quotes inside phrase/near field\n"));
-	return false;
+	m_text = neutchars(m_text, "\"");
     }
     string s = string("\"") + m_text + string("\"");
     bool useNear = (m_tp == SCLT_NEAR);
